@@ -32,8 +32,8 @@ class EventChannel_impl;
 // PUSH
 
 class ProxyPushConsumer_impl :
-  virtual public CosEventComm::PushConsumer_skel,
-  virtual public CosEventChannelAdmin::ProxyPushConsumer_skel {
+  virtual public POA_CosEventComm::PushConsumer,
+  virtual public POA_CosEventChannelAdmin::ProxyPushConsumer {
 public:
     ProxyPushConsumer_impl (EventChannel_impl* impl);
 
@@ -49,8 +49,8 @@ private:
 
 
 class ProxyPushSupplier_impl :
-  virtual public CosEventComm::PushSupplier_skel,
-  virtual public CosEventChannelAdmin::ProxyPushSupplier_skel,
+  virtual public POA_CosEventComm::PushSupplier,
+  virtual public POA_CosEventChannelAdmin::ProxyPushSupplier,
   public CORBA::RequestCallback {
 public:
     ProxyPushSupplier_impl (EventChannel_impl* impl);
@@ -65,34 +65,38 @@ private:
     void callback (CORBA::Request_ptr req, CORBA::RequestCallback::Event);
     EventChannel_impl* channel;
     CosEventComm::PushConsumer_var consumer;
-    list<CORBA::Request_var> requests;
+    MICOMT::Locked<std::list<CORBA::Request_var> > requests;
 };
 
 
 // PULL
 
-class PullSupplier_skel2 : virtual public CosEventComm::PullSupplier_skel {
+class PullSupplier_skel2 : virtual public POA_CosEventComm::PullSupplier {
 public:
-    PullSupplier_skel2 (const CORBA::BOA::ReferenceData & =
-                        CORBA::BOA::ReferenceData());
+    PullSupplier_skel2 ();
     PullSupplier_skel2 (CORBA::Object_ptr _obj);
     virtual ~PullSupplier_skel2();
 
-    virtual bool dispatch (CORBA::StaticServerRequest_ptr _req,
-                           CORBA::Environment &_env);
+    // not used for POA since POA-based dispatch method is not virtual
+    //    virtual bool dispatch (CORBA::StaticServerRequest_ptr _req);
+    // use invoke instead of dispatch
+    virtual void invoke(CORBA::StaticServerRequest_ptr req);
 
     virtual void pull (CORBA::StaticServerRequest_ptr req) = 0;
 };
 
 class ProxyPullSupplier_impl :
   virtual public PullSupplier_skel2,
-  virtual public CosEventChannelAdmin::ProxyPullSupplier_skel {
+  virtual public POA_CosEventChannelAdmin::ProxyPullSupplier {
 public:
     ProxyPullSupplier_impl (EventChannel_impl *impl);
 
     void connect_pull_consumer (CosEventComm::PullConsumer_ptr pull_consumer);
     void disconnect_pull_supplier ();
 
+    // added for POA port
+    virtual void invoke(CORBA::StaticServerRequest_ptr req);
+
     void pull (CORBA::StaticServerRequest_ptr req);
       
     CORBA::Any* pull ();
@@ -104,13 +108,13 @@ private:
     CosEventComm::PullConsumer_var consumer;
     CORBA::Boolean connected;
 
-    list<CORBA::StaticServerRequest_var> requests;
-    list<CORBA::Any> events;
+    MICOMT::Locked<std::list<CORBA::StaticServerRequest_var> > requests;
+    MICOMT::Locked<std::list<CORBA::Any> > events;
 };
 
 class ProxyPullConsumer_impl :
-  virtual public CosEventComm::PullConsumer_skel,
-  virtual public CosEventChannelAdmin::ProxyPullConsumer_skel,
+  virtual public POA_CosEventComm::PullConsumer,
+  virtual public POA_CosEventChannelAdmin::ProxyPullConsumer,
   public CORBA::RequestCallback {
 public:
     ProxyPullConsumer_impl (EventChannel_impl *impl);
@@ -130,7 +134,7 @@ private:
 
 // ADMIN
 
-class ConsumerAdmin_impl : public CosEventChannelAdmin::ConsumerAdmin_skel {
+class ConsumerAdmin_impl : public POA_CosEventChannelAdmin::ConsumerAdmin {
 public: 
     ConsumerAdmin_impl (EventChannel_impl *channel);
 
@@ -141,7 +145,7 @@ private:
     EventChannel_impl* event_channel;
 };
 
-class SupplierAdmin_impl : public CosEventChannelAdmin::SupplierAdmin_skel {
+class SupplierAdmin_impl : public POA_CosEventChannelAdmin::SupplierAdmin {
 public: 
     SupplierAdmin_impl (EventChannel_impl *channel);
 
@@ -154,11 +158,12 @@ private:
 
 // EVENT CHANNEL
 
-class EventChannel_impl : public CosEventChannelAdmin::EventChannel_skel {
+class EventChannel_impl : public POA_CosEventChannelAdmin::EventChannel {
     CORBA::ULong _listeners;
+    MICOMT::Mutex _listeners_mutex;
     CORBA::Long _max_queue_size;
 protected:
-    EventChannel_impl (const CORBA::BOA::ReferenceData&);
+    EventChannel_impl ();
 
 public:
     EventChannel_impl (CORBA::Object_ptr obj);
@@ -186,10 +191,10 @@ public:
     }
 
 private:
-    list<CosEventChannelAdmin::ProxyPushSupplier_var> _push_supp;
-    list<CosEventChannelAdmin::ProxyPushConsumer_var> _push_cons;
-    list<CosEventChannelAdmin::ProxyPullSupplier_var> _pull_supp;
-    list<CosEventChannelAdmin::ProxyPullConsumer_var> _pull_cons;
+    MICOMT::Locked<std::list<CosEventChannelAdmin::ProxyPushSupplier_var> > _push_supp;
+    MICOMT::Locked<std::list<CosEventChannelAdmin::ProxyPushConsumer_var> > _push_cons;
+    MICOMT::Locked<std::list<CosEventChannelAdmin::ProxyPullSupplier_var> > _pull_supp;
+    MICOMT::Locked<std::list<CosEventChannelAdmin::ProxyPullConsumer_var> > _pull_cons;
 
     CosEventChannelAdmin::SupplierAdmin_var supplier_admin;
     CosEventChannelAdmin::ConsumerAdmin_var consumer_admin;
@@ -198,10 +203,10 @@ private:
 // FACTORY
 
 class EventChannelFactory_impl : 
-  public SimpleEventChannelAdmin::EventChannelFactory_skel {
+  public POA_SimpleEventChannelAdmin::EventChannelFactory {
     CORBA::Long _max_queue_size;
 protected:
-    EventChannelFactory_impl (const CORBA::BOA::ReferenceData&);
+    EventChannelFactory_impl ();
 
 public:
     EventChannelFactory_impl (CORBA::Object_ptr obj);
@@ -212,10 +217,4 @@ public:
     static void _shutdown ();
 };
 
-
-class EventChannelLoader : public CORBA::BOAObjectRestorer {
-public:
-  CORBA::Boolean restore (CORBA::Object_ptr);
-};
-
 #endif
