@@ -37,8 +37,10 @@
 #include <iostream.h>
 #endif
 
-typedef map<RoleNameKey,CosGraphs::Traversal::TraversalScopedId,less<RoleNameKey> > WorkedRoles;
-typedef map<RoleNameKey,CosGraphs::Role_ptr,less<RoleNameKey> > NewRoles;
+using std::string;
+
+typedef std::map<RoleNameKey,CosGraphs::Traversal::TraversalScopedId,std::less<RoleNameKey> > WorkedRoles;
+typedef std::map<RoleNameKey,CosGraphs::Role_ptr,std::less<RoleNameKey> > NewRoles;
 typedef IfaceSequenceTmpl<CosCompoundExternalization::Node_var,CosCompoundExternalization::Node_ptr> NewNodes;
 
 const char tag_object = 0xF0;
@@ -135,10 +137,10 @@ void StreamIO_impl::write_object(CosStream::Streamable_ptr aStreamable)
     (*aStreamable).externalize_to_stream(_sio);
 }
 
-CORBA::Boolean StreamIO_impl::was_extern(vector<CosObjectIdentity::ObjectIdentifier>* vec_,
+CORBA::Boolean StreamIO_impl::was_extern(std::vector<CosObjectIdentity::ObjectIdentifier>* vec_,
 					 CosObjectIdentity::ObjectIdentifier id)
 {
-    vector<CosObjectIdentity::ObjectIdentifier>::iterator j;
+    std::vector<CosObjectIdentity::ObjectIdentifier>::iterator j;
     for(j = vec_->begin();j != vec_->end();++j)
 	if (*j == id)
 	    return TRUE;
@@ -151,10 +153,10 @@ void StreamIO_impl::write_graph(CosCompoundExternalization::Node_ptr starting_no
     if (iotype != out)
 	return;
     CosStream::StreamIO_ptr _sio = this->_this();
-    vector<CosObjectIdentity::ObjectIdentifier>* done_nodes =
-	new vector<CosObjectIdentity::ObjectIdentifier>;
-    vector<CosObjectIdentity::ObjectIdentifier>* done_rel =
-	new vector<CosObjectIdentity::ObjectIdentifier>;
+    std::vector<CosObjectIdentity::ObjectIdentifier>* done_nodes =
+	new std::vector<CosObjectIdentity::ObjectIdentifier>;
+    std::vector<CosObjectIdentity::ObjectIdentifier>* done_rel =
+	new std::vector<CosObjectIdentity::ObjectIdentifier>;
 // Externalize Root Node
     CosObjectIdentity::ObjectIdentifier starting_node_id = starting_node->constant_random_id();
 // End
