@@ -34,8 +34,8 @@
 static void
 usage(const char* progName)
 {
-	cerr << "Usage:\n";
-	cerr << progName << " [options]\n"
+    	std::cerr << "Usage:\n";
+	std::cerr << progName << " [options]\n"
 	"\n"
 	"Options:\n"
 	"-h, --help                Show this message.\n"
@@ -65,7 +65,7 @@ int main( int argc, char *argv[] )
 	else if(strcmp(argv[i], "--version") == 0 ||
 		strcmp(argv[i], "-v") == 0)
 	{
-	    cerr << "Version of CosExternalizationReference Service Factories is " << MICO_VERSION << endl;
+	    std::cerr << "Version of CosExternalizationReference Service Factories is " << MICO_VERSION << std::endl;
 	    return 0;
 	}
 	else if(strcmp(argv[i], "--with-naming") == 0 ||
@@ -76,8 +76,8 @@ int main( int argc, char *argv[] )
 				type = RegisterHelper::trading;
 	else
 	{
-	    cerr << progName << ": unknown option `"
-		 << argv[i] << "'\n" << endl;
+	    std::cerr << progName << ": unknown option `"
+		 << argv[i] << "'\n" << std::endl;
 	    usage(progName);
 	    return 1;
 	}
