@@ -23,7 +23,7 @@
 #ifndef _NamingClient_h_
 #define _NamingClient_h_
 
-#include <mico/CosNaming.h>
+#include <coss/CosNaming.h>
 
 class NamingClient {
 public:
@@ -50,5 +50,5 @@ private:
   CosNaming::NamingContextExt_var root_nce;
   CosNaming::Name current_path;
 };
-void printname(ostream &,const CosNaming::Name& name);
+void printname(std::ostream &,const CosNaming::Name& name);
 #endif
