@@ -52,10 +52,10 @@ private:
 
   typedef std::map<CosNaming::NameComponent, NmCtxBinding,
       str_less> BindingTable;
-  BindingTable table;
+  MICOMT::Locked<BindingTable> table;
 
-  typedef std::set<NamingContext_impl *, std::less<NamingContext_impl*> >
-  ServantMap;
+  typedef MICOMT::Locked<std::set<NamingContext_impl *, 
+                                  std::less<NamingContext_impl*> > > ServantMap;
   static ServantMap svmap;
 
 public:
@@ -73,12 +73,12 @@ private:
   typedef std::map<std::string, LoadBalanceData, std::less<std::string> >
   NameKindTable;
 
-  NameKindTable tbLoadBalanceTable;
+  MICOMT::Locked<NameKindTable> tbLoadBalanceTable;
 
 protected:
   void _do_bind (const CosNaming::Name& n, CORBA::Object_ptr obj,
 		 CosNaming::BindingType btype, CORBA::Boolean rebind);
-
+  CosNaming::NamingContext_ptr _force_local(CosNaming::NamingContext_ptr nc_in);
   std::string FindNameComponent (const CosNaming::NameComponent *pNameComponent,
 				 LoadBalanceData *pstLoadBalanceData);
   void AddLoadBalanceEntry (const CosNaming::NameComponent *pNameComponent);
@@ -133,6 +133,7 @@ class BindingIterator_impl :
   virtual public PortableServer::RefCountServantBase
 {
 private:
+  MICOMT::Mutex blist_lock_;
   CORBA::ULong idx;
   CosNaming::BindingList blist;
   CORBA::ORB_var useorb;
