@@ -23,22 +23,25 @@
  */
 
 
+#include <coss/CosRelationships.h>
+#include <coss/Role_impl.h>
+#include <coss/RelationshipIterator_impl.h>
 #include <string.h>
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iostream>
+#include <fstream>
+#else
 #include <iostream.h>
 #include <fstream.h>
+#endif
 #include <unistd.h>
-#include <mico/CosRelationships.h>
-#include <mico/Role_impl.h>
-#include <mico/RelationshipIterator_impl.h>
 
 
 //#define DEBUG 1
 //#define DEBUG2 1
 
 Role_impl::Role_impl ()
-#ifndef _WINDOWS
   : POA_CosRelationships::Role ()
-#endif
 {
 #if DEBUG2
   cout << "  <Role_impl> constructor\n";
@@ -54,9 +57,7 @@ Role_impl::Role_impl ()
 }
 
 Role_impl::Role_impl (CosRelationships::RelatedObject_ptr obj)
-#ifndef _WINDOWS
   : POA_CosRelationships::Role ()
-#endif
 {
 #if DEBUG2
   cout << "  <Role_impl> constructor with params\n";
