@@ -5,13 +5,8 @@
 #include "misc.h"
 
 class Trader;
-#ifdef _WINDOWS
-class Proxy_impl : public TraderComponents, public SupportAttributes,
-	      public CosTrading::Proxy_skel
-#else
 class Proxy_impl : virtual public TraderComponents, virtual public SupportAttributes,
 	      virtual public CosTrading::Proxy_skel
-#endif
 {
 public:  
   Proxy_impl( Trader* _trader );
@@ -19,7 +14,7 @@ public:
 #ifdef HAVE_EXPLICIT_METHOD_OVERRIDE
   virtual void *_narrow_helper( const char *repoid )
   {
-      return this->MICO_SCOPE(CosTrading,Proxy::_narrow_helper)( repoid );
+      return this->CosTrading::Proxy::_narrow_helper( repoid );
   }
 #endif
 
