@@ -6,19 +6,10 @@
 
 #include "misc.h"
 
-#ifdef USE_CORBA_2_1
-#define CORBA_CXX_PREFIX(x) _##x
-#else
 #define CORBA_CXX_PREFIX(x) _cxx_##x
-#endif
 
-#ifdef _WINDOWS
-class Register_impl : public TraderComponents, public SupportAttributes,
-		      virtual public CosTrading::Register_skel
-#else
 class Register_impl : virtual public TraderComponents, virtual public SupportAttributes,
 		      virtual public CosTrading::Register_skel
-#endif
 {
 public:
   Register_impl( Trader *_trader );
@@ -26,7 +17,7 @@ public:
 #ifdef HAVE_EXPLICIT_METHOD_OVERRIDE
   virtual void *_narrow_helper( const char *repoid )
   {
-      return this->MICO_SCOPE(CosTrading,Register::_narrow_helper)( repoid );
+      return this->CosTrading::Register::_narrow_helper( repoid );
   }
 #endif
 
