@@ -1,4 +1,4 @@
-#ifdef _WINDOWS
+#if defined(_WIN32) && !defined(__MINGW32__)
 #include <mico/config-win32.h>
 #include <io.h>
 #include <malloc.h>
@@ -6,11 +6,20 @@
 
 #pragma warning (disable: 4018)
 
-char *index( char *s, char c );
-char *rindex( char *s, char c );
+// char *index( char *s, char c ); // no (more) need for an extra function
+#define index(s,c) strchr(s,c)
+// char *rindex( char *s, char c ); // no (more) need for an extra function
+#define rindex(s,c) strrchr(s,c)
 
 #else
+
 #include <mico/config.h>
+
+#ifdef __MINGW32__
+#define index(s,c) strchr(s,c)
+#define rindex(s,c) strrchr(s,c)
+#endif
+
 #endif
 
 #define BITS_PER_UNIT SIZEOF_UNSIGNED_CHAR
