@@ -114,21 +114,6 @@ imr_info (const vector<string> &args, CORBA::ImplRepository_ptr imr)
     cout << setw(20) << "server name: " << args[0] << endl;
     cout << setw(20) << "activation mode: ";
     switch (impl->mode()) {
-    case CORBA::ImplementationDef::ActivateShared:
-	cout << "shared";
-	break;
-    case CORBA::ImplementationDef::ActivateUnshared:
-	cout << "unshared";
-	break;
-    case CORBA::ImplementationDef::ActivatePerMethod:
-	cout << "permethod";
-	break;
-    case CORBA::ImplementationDef::ActivatePersistent:
-	cout << "persistent";
-	break;
-    case CORBA::ImplementationDef::ActivateLibrary:
-	cout << "library";
-	break;
     case CORBA::ImplementationDef::ActivatePOA:
         cout << "poa";
 	break;
@@ -218,32 +203,19 @@ imr_create (const vector<string> &args, CORBA::ImplRepository_ptr imr)
     }
 
     CORBA::ImplementationDef::ActivationMode mode;
-    if (args[1] == "persistent")
-	mode = CORBA::ImplementationDef::ActivatePersistent;
-    else if (args[1] == "shared")
-	mode = CORBA::ImplementationDef::ActivateShared;
-    else if (args[1] == "unshared")
-	mode = CORBA::ImplementationDef::ActivateUnshared;
-    else if (args[1] == "permethod")
-	mode = CORBA::ImplementationDef::ActivatePerMethod;
-    else if (args[1] == "library")
-	mode = CORBA::ImplementationDef::ActivateLibrary;
-    else if (args[1] == "poa")
+    if (args[1] == "poa")
 	mode = CORBA::ImplementationDef::ActivatePOA;
     else {
 	cout << "invalid activation mode: " << args[1] << endl;
-	cout << "valid modes are: persistent, shared, unshared, "
-	     << "permethod, library, poa"
+	cout << "valid modes are: poa"
 	     << endl;
 	return 1;
     }
 
     string command;
     if (args.size() < 2) {
-      if (mode != CORBA::ImplementationDef::ActivatePersistent) {
 	cout << prog_name << "create needs a command" << endl;
 	return 1;
-      }
     }
     else {
       command = args[2];
@@ -289,41 +261,7 @@ imr_activate (const vector<string> &args, CORBA::ImplRepository_ptr imr)
     assert (impls->length() == 1);
 
     CORBA::ORB_var orb = CORBA::ORB_instance ("mico-local-orb");
-    CORBA::Object_var obj;
-    //
-    // Commented out because BOA mediator is not changed to use ORBMsgId
-    // instead of MsgId yet.
-    //
-//  #ifndef HAVE_THREADS
-//      if (args.size() > 1) {
-//  	// try given address
-//  	obj = orb->bind ("IDL:omg.org/CORBA/OAMediator:1.0",
-//  			 args[1].c_str());
-//      }
-//      if (CORBA::is_nil (obj)) {
-//  	// try address of the impl repo
-//  	const CORBA::Address *addr = imr->_ior()->addr();
-//  	obj = orb->bind ("IDL:omg.org/CORBA/OAMediator:1.0",
-//  			 addr->stringify().c_str());
-//      }
-//      if (CORBA::is_nil (obj)) {
-//  	// try default addresses 
-//  	obj = orb->bind ("IDL:omg.org/CORBA/OAMediator:1.0");
-//      }
-//      if (CORBA::is_nil (obj)) {
-//  	cout << "error: cannot connect to micod" << endl;
-//  	return 1;
-//      }
-//      CORBA::OAMediator_var oamed = CORBA::OAMediator::_narrow (obj);
-//      if (oamed->force_activation (impls[(CORBA::ULong)0])) {
-//        return 0;
-//      }
-//  #endif // HAVE_THREADS
-    /*
-     * Try again with POA Mediator
-     */
-
-    obj = CORBA::Object::_nil ();
+    CORBA::Object_var obj = CORBA::Object::_nil ();
 
     if (args.size() > 1) {
 	// try given address
