@@ -8,9 +8,10 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <signal.h>
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iomanip>
+#else
 #include <iomanip.h>
-#ifndef HAVE_THREADS
-#include "mediator.h"
 #endif
 #include "poamediator.h"
 #include "imr_impl.h"
