@@ -1,6 +1,7 @@
 /*
  *  MICO --- an Open Source CORBA implementation
  *  Copyright (C) 1998 Frank Pilhofer
+ *  Copyright (c) 1999-2008 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +21,15 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "imr_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #include <CORBA.h>
 #include <mico/impl.h>
 #include <mico/util.h>
@@ -27,6 +37,11 @@
 #include <mico/template_impl.h>
 #include "poamediator.h"
 
+#endif // FAST_PCH
+
+
+using namespace std;
+
 /*
  * ----------------------------------------------------------------------
  * The POA Mediator
@@ -59,7 +74,7 @@ POAMediatorImpl::SvInf::SvInf ()
  */
 
 POAMediatorImpl::POAMediatorImpl (CORBA::ORB_ptr _orb, CORBA::Boolean _forward)
-  : invqueue (this, _orb)
+  : invqueue (this, _orb), _M_global_lock (FALSE, MICOMT::Mutex::Recursive)
 {
   orb = _orb;
   forward = _forward;
@@ -73,6 +88,8 @@ POAMediatorImpl::POAMediatorImpl (CORBA::ORB_ptr _orb, CORBA::Boolean _forward)
 
 POAMediatorImpl::~POAMediatorImpl ()
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   orb->unregister_oa (this);
 
   MapSvInf::iterator it;
@@ -91,6 +108,8 @@ POAMediatorImpl::~POAMediatorImpl ()
 char *
 POAMediatorImpl::create_impl (const char * svid, const char * ior)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   CORBA::ImplRepository::ImplDefSeq_var ids =
     imr->find_by_name (svid);
 
@@ -108,6 +127,8 @@ POAMediatorImpl::create_impl (const char * svid, const char * ior)
 void
 POAMediatorImpl::activate_impl (const char * svid)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   if (svmap[svid].pstate == Stopped ||
       svmap[svid].pstate == Holding) {
     return;
@@ -125,6 +146,8 @@ POAMediatorImpl::activate_impl (const char * svid)
 void
 POAMediatorImpl::deactivate_impl (const char * svid)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   SvInf &inf = svmap[svid];
 
   assert (inf.pstate == Stopped || inf.proc);
@@ -160,6 +183,8 @@ POAMediatorImpl::deactivate_impl (const char * svid)
 CORBA::Boolean
 POAMediatorImpl::force_activation (CORBA::ImplementationDef_ptr impl)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   CORBA::String_var svid = impl->name ();
   SvInf &inf = svmap[svid.in()];
 
@@ -192,13 +217,14 @@ POAMediatorImpl::force_activation (CORBA::ImplementationDef_ptr impl)
   default:
     assert (0);
   }
-
   return create_server (svid);
 }
 
 CORBA::Boolean
 POAMediatorImpl::hold (CORBA::ImplementationDef_ptr impl)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   CORBA::String_var svid = impl->name ();
   SvInf &inf = svmap[svid.in()];
 
@@ -228,6 +254,8 @@ POAMediatorImpl::hold (CORBA::ImplementationDef_ptr impl)
 CORBA::Boolean
 POAMediatorImpl::stop (CORBA::ImplementationDef_ptr impl)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   CORBA::String_var svid = impl->name ();
   SvInf &inf = svmap[svid.in()];
 
@@ -272,6 +300,8 @@ POAMediatorImpl::stop (CORBA::ImplementationDef_ptr impl)
 CORBA::Boolean
 POAMediatorImpl::_cxx_continue (CORBA::ImplementationDef_ptr impl)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   CORBA::String_var svid = impl->name ();
   SvInf &inf = svmap[svid.in()];
 
@@ -302,6 +332,8 @@ POAMediatorImpl::_cxx_continue (CORBA::ImplementationDef_ptr impl)
 CORBA::Boolean
 POAMediatorImpl::create_server (const char * svid)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   SvInf &inf = svmap[svid];
 
   if (inf.pstate == Started || inf.pstate == Active) {
@@ -373,7 +405,7 @@ POAMediatorImpl::create_server (const char * svid)
     command += s;
   }
 
-  s = orb->object_to_string (this);
+  s = orb->object_to_string(my_ref_);
   command += " -POARemoteIOR ";
   command += s;
 
@@ -383,6 +415,12 @@ POAMediatorImpl::create_server (const char * svid)
   return inf.proc->run();
 }
 
+void
+POAMediatorImpl::set_own_ref(CORBA::Object_ptr obj)
+{
+    my_ref_ = CORBA::Object::_duplicate(obj);
+}
+
 /*
  * OA Interface
  */
@@ -396,6 +434,8 @@ POAMediatorImpl::get_oaid () const
 CORBA::Boolean
 POAMediatorImpl::has_object (CORBA::Object_ptr obj)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   /*
    * Extract Objectkey from IOR. It starts with the POAImplName.
    * Take care of escaped slashes.
@@ -462,12 +502,23 @@ POAMediatorImpl::is_local () const
     return TRUE;
 }
 
+
+#ifdef USE_CSL2
+CORBA::Principal_ptr
+POAMediatorImpl::get_principal(CORBA::Object_ptr obj){
+  assert(0);
+  return (CORBA::Principal_ptr)0;
+}
+#endif /* USE_CSL2  */
+
 CORBA::Boolean
-POAMediatorImpl::invoke (MsgId id, CORBA::Object_ptr obj,
+POAMediatorImpl::invoke (CORBA::ORBMsgId id, CORBA::Object_ptr obj,
 			 CORBA::ORBRequest *req,
 			 CORBA::Principal_ptr pr,
 			 CORBA::Boolean response_exp)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   /*
    * Extract Objectkey from IOR. It starts with the POAImplName.
    */
@@ -577,7 +628,7 @@ POAMediatorImpl::invoke (MsgId id, CORBA::Object_ptr obj,
    * do the invocation (on the remote object)
    */
 
-  MsgId orbid = orb->new_msgid();
+  CORBA::ORBMsgId orbid = orb->new_orbid (orb->new_msgid());
 
   if (response_exp) {
     requests[orbid] = id;
@@ -588,10 +639,12 @@ POAMediatorImpl::invoke (MsgId id, CORBA::Object_ptr obj,
 }
 
 CORBA::Boolean
-POAMediatorImpl::bind (MsgId id, const char *repoid,
+POAMediatorImpl::bind (CORBA::ORBMsgId id, const char *repoid,
 		       const CORBA::ORB::ObjectTag &tag,
 		       CORBA::Address *addr)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   if (addr && !addr->is_local()) {
     return FALSE;
   }
@@ -657,12 +710,12 @@ POAMediatorImpl::bind (MsgId id, const char *repoid,
    * not.
    */
 
-  vector<MsgId> msgids;
+  vector<CORBA::ORBMsgId> msgids;
   for (it = svmap.begin(); it != svmap.end(); it++) {
     if ((*it).second.pstate != Active) {
       continue;
     }
-    msgids.push_back (orb->new_msgid());
+    msgids.push_back (orb->new_orbid (orb->new_msgid()));
     requests[msgids.back()] = id;
   }
 
@@ -679,8 +732,8 @@ POAMediatorImpl::bind (MsgId id, const char *repoid,
     assert (addr);
 
     assert (msgids.size() > 0);
-    MsgId orbid = _orbnc()->bind_async (repoid, tag, addr, this,
-					msgids.back());
+    CORBA::ORBMsgId orbid = orb->bind_async (repoid, tag, addr, this,
+					     msgids.back());
     msgids.pop_back();
     assert (orbid != 0);
   }
@@ -689,7 +742,7 @@ POAMediatorImpl::bind (MsgId id, const char *repoid,
 }
 
 CORBA::Boolean
-POAMediatorImpl::locate (MsgId id, CORBA::Object_ptr)
+POAMediatorImpl::locate (CORBA::ORBMsgId id, CORBA::Object_ptr)
 {
   orb->answer_locate (id, CORBA::LocateHere, CORBA::Object::_nil(), 0);
   return TRUE;
@@ -702,8 +755,10 @@ POAMediatorImpl::skeleton (CORBA::Object_ptr)
 }
 
 void
-POAMediatorImpl::cancel (MsgId id)
+POAMediatorImpl::cancel (CORBA::ORBMsgId id)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   int again = 1;
   while (again) {
     again = 0;
@@ -722,6 +777,8 @@ POAMediatorImpl::cancel (MsgId id)
 void
 POAMediatorImpl::shutdown_server ()
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   /*
    * Signal servers
    */
@@ -737,7 +794,8 @@ POAMediatorImpl::shutdown_server ()
    */
 
   CORBA::Boolean waiting;
-  CORBA::Timeout t (orb->dispatcher(), 10000);
+  OSMisc::TimeVal t1 = OSMisc::gettime ();
+  OSMisc::TimeVal t2;
 
   do {
     waiting = FALSE;
@@ -751,8 +809,9 @@ POAMediatorImpl::shutdown_server ()
     if (waiting) {
       orb->perform_work ();
     }
+    t2 = OSMisc::gettime();
   }
-  while (!t.done() && waiting);
+  while (waiting && (t2.tv_sec - t1.tv_sec < 60));
 
   for (MapSvInf::iterator it2 = svmap.begin(); it2 != svmap.end(); it2++) {
     if ((*it2).second.proc != 0) {
@@ -764,25 +823,53 @@ POAMediatorImpl::shutdown_server ()
 void
 POAMediatorImpl::shutdown (CORBA::Boolean wait_for_completion)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
   invqueue.fail();
   orb->answer_shutdown (this);
 }
 
 void
-POAMediatorImpl::answer_invoke (CORBA::ULong, CORBA::Object_ptr,
+POAMediatorImpl::answer_invoke (CORBA::ORBMsgId, CORBA::Object_ptr,
 				CORBA::ORBRequest *, CORBA::InvokeStatus)
 {
   assert (0);
 }
 
+CORBA::Boolean
+POAMediatorImpl::validate_connection
+(CORBA::Object_ptr obj,
+ CORBA::PolicyList_out inconsistent_policies)
+{
+    // shouldn't be called
+    assert(0);
+    return FALSE;
+}
+
+void
+POAMediatorImpl::timedout_invoke(CORBA::ORBMsgId)
+{
+    // shouldn't be called
+    assert(0);
+}
+
 /*
  * ORB Callback
  */
 
-void
-POAMediatorImpl::callback (CORBA::ORB_ptr orb, MsgId id,
-			   CORBA::ORBCallback::Event ev)
+CORBA::Boolean
+POAMediatorImpl::waitfor (CORBA::ORB_ptr, CORBA::ORBMsgId msgid,
+			  CORBA::ORBCallback::Event ev, CORBA::Long tmout)
 {
+    assert(0);
+    return TRUE;
+}
+
+void
+POAMediatorImpl::notify (CORBA::ORB_ptr orb, CORBA::ORBMsgId id,
+			 CORBA::ORBCallback::Event ev)
+{
+  MICOMT::AutoLock __lock(_M_global_lock);
+
   switch (ev) {
   case CORBA::ORBCallback::Invoke:
     {
@@ -809,7 +896,7 @@ POAMediatorImpl::callback (CORBA::ORB_ptr orb, MsgId id,
       MapIdId::iterator i = requests.find (id);
       assert (i != requests.end());
 
-      MsgId id2 = (*i).second;
+      CORBA::ORBMsgId id2 = (*i).second;
       requests.erase (i);
 
       if (stat == CORBA::LocateHere) {
@@ -850,6 +937,7 @@ void
 POAMediatorImpl::callback (MICO::Process * proc,
 			   MICO::ProcessCallback::Event ev)
 {
+  MICOMT::AutoLock __lock(_M_global_lock);
   /*
    * Find appropriate server
    */
