@@ -2,6 +2,7 @@
 /*
  *  MICO --- an Open Source CORBA implementation
  *  Copyright (C) 1998 Frank Pilhofer
+ *  Copyright (c) 1999-2008 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -118,6 +119,12 @@ public:
 		      CORBA::ORBRequest *,
 		      CORBA::InvokeStatus);
 
+  virtual CORBA::Boolean
+  validate_connection(CORBA::Object_ptr, CORBA::PolicyList_out);
+
+  virtual void
+  timedout_invoke(CORBA::ORBMsgId);
+
   /*
    * Callbacks (ORB, Process)
    */
