@@ -26,14 +26,17 @@
 #include <time.h>
 #include <string.h>
 
-#include <mico/CosRelationships.h>
-#include <mico/CosGraphs.h>
-#include <mico/CosContainment.h>
-#include <mico/CosReference.h>
-#include <mico/CosGraphsExtension.h>
+#include <coss/CosRelationships.h>
+#include <coss/CosGraphs.h>
+#include <coss/CosContainment.h>
+#include <coss/CosReference.h>
+#include <coss/CosGraphsExtension.h>
 #include "Documents.h"
 #include "Test.h"
 
+
+using namespace std;
+
 int main( int argc, char *argv[] )
 {
   //ORB initialization
@@ -281,18 +284,21 @@ int main( int argc, char *argv[] )
   Documents::Figure_var fig2;
   CosGraphs::Node_var node1;
   CosGraphs::Node_var node2;
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     fig1 = Documents::Figure::_narrow (figure_factory->create ("fig1.png"));
     node1 = CosGraphs::Node::_duplicate (node_factory->create_node (fig1));
     role1 = CosContainment::ContainsRole::_narrow 
       (contains_factory->create_role (node1));
+#ifdef HAVE_EXCEPTIONS
   }  
-  catch (CosRelationships::RoleFactory::RelatedObjectTypeError &ex1)
+  catch (CosRelationships::RoleFactory::RelatedObjectTypeError_catch &ex1)
     {
       cout << "RelatedObjectTypeError!\n" << flush;
       right_role = FALSE;
     }
-
+#endif
   if (!CORBA::is_nil (role1)) {
     cout << "ok.\n" << flush;
   }
@@ -312,13 +318,16 @@ int main( int argc, char *argv[] )
   exception = FALSE;
   cout << "Checking Role::destroy ()  ..." << flush;
   role1->destroy ();
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     CORBA::Object_var x = role1->related_object ();
+#ifdef HAVE_EXCEPTIONS
   }
-  catch (CORBA::SystemException &ex) {
+  catch (CORBA::SystemException_catch &ex) {
     exception = TRUE;
   }
- 
+#endif
   if (exception)
     cout << "ok.\n" << flush;
   else {
@@ -328,14 +337,17 @@ int main( int argc, char *argv[] )
   exception = FALSE;
   cout << "Checking RoleFactory::RelatedObjectTypeError exception  ..." 
        << flush;
-  
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     role1 = CosContainment::ContainsRole::_narrow 
       (contains_factory->create_role 
        (Documents::Figure::_duplicate (fig1)));
-  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError& ex1) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError_catch &ex1) {
     exception = TRUE;
   }
+#endif
 
   if (exception)
     cout << "ok.\n" << flush;
@@ -346,14 +358,17 @@ int main( int argc, char *argv[] )
   cout << "Checking RoleFactory::NilRelatedObject exception  ..." << flush;
   exception = FALSE;
 
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     role1 = CosContainment::ContainsRole::_narrow 
       (contains_factory->create_role 
        (CosGraphs::Node::_nil ()));
-  } catch (CosRelationships::RoleFactory::NilRelatedObject &ex1) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CosRelationships::RoleFactory::NilRelatedObject_catch &ex1) {
     exception = TRUE;
   }
-
+#endif
   if (exception)
     cout << "ok.\n" << flush;
   else {
@@ -361,8 +376,9 @@ int main( int argc, char *argv[] )
   }
   
 
-
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     fig2 = Documents::Figure::_narrow (figure_factory->create ("fig2.jpg"));
     node2 = CosGraphs::Node::_narrow 
       (node_factory->create_node (fig2));
@@ -374,9 +390,11 @@ int main( int argc, char *argv[] )
       (contains_factory->create_role
        (node1));
 
-  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError &ex1) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError_catch &ex1) {
     cout << "RelatedObjectTypeError!\n" << flush;
   }
+#endif
 
   assert (!CORBA::is_nil (role1));
   assert (!CORBA::is_nil (role2));
@@ -390,16 +408,19 @@ int main( int argc, char *argv[] )
   nr[1].name = CORBA::string_dup ("ContainedInRole");
   nr[1].aRole = CosRelationships::Role::_duplicate (role2);
   
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     cout << "DegreeError exception!!!\n" << flush;
     cout << "Required degree is " << ex->required_degree << "\n" << flush;
     relship1 = CosContainment::Relationship::_nil ();
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     cout << "DuplicateRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i<(ex->culprits).length () ; i++) {
@@ -407,7 +428,7 @@ int main( int argc, char *argv[] )
     }
     relship1 = CosContainment::Relationship::_nil ();
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     cout << "UnknownRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i< (ex->culprits).length (); i++) {
@@ -416,7 +437,7 @@ int main( int argc, char *argv[] )
     relship1 = CosContainment::Relationship::_nil ();
     cout << "End of catch statement!\n" << flush;
   }
-  
+#endif
   if (!CORBA::is_nil (relship1)) {
     cout << "ok.\n" << flush;
   }
@@ -433,17 +454,20 @@ int main( int argc, char *argv[] )
   nr[0].aRole = CosRelationships::Role::_duplicate (role1);
   nr[1].name = strdup ("ConatinedInRole");
   nr[1].aRole = CosRelationships::Role::_duplicate (role2);
- 
+  
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow 
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     cout << "DegreeError exception!!!\n" << flush;
     cout << "Required degree is " << ex->required_degree << "\n" << flush;
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     cout << "DuplicateRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i<(ex->culprits).length () ; i++) {
@@ -451,7 +475,7 @@ int main( int argc, char *argv[] )
     }
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     //       cout << "UnknownRoleName exception!!!\n" << flush;
     //       cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" 
     //       << flush;
@@ -460,7 +484,7 @@ int main( int argc, char *argv[] )
     //       }
     state_good = TRUE;
   }
-
+#endif
   if (state_good) {
     cout << "ok.\n" << flush;
   }
@@ -478,16 +502,19 @@ int main( int argc, char *argv[] )
   nr[1].name = CORBA::string_dup ("ContainsRole");
   nr[1].aRole = CosRelationships::Role::_duplicate (role1);
  
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     cout << "DegreeError exception!!!\n" << flush;
     cout << "Required degree is " << ex->required_degree << "\n" << flush;
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     //       cout << "DuplicateRoleName exception!!!\n" << flush;
     //       cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n"
     //            << flush;
@@ -496,7 +523,7 @@ int main( int argc, char *argv[] )
     //       }
     state_good = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     cout << "UnknownRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i< (ex->culprits).length (); i++) {
@@ -505,7 +532,7 @@ int main( int argc, char *argv[] )
     exception = TRUE;
     cout << "End of catch statement!\n" << flush;
   }
-
+#endif
   if (state_good) 
     cout << "ok.\n" << flush;
   else
@@ -523,17 +550,19 @@ int main( int argc, char *argv[] )
   nr[2].name = CORBA::string_dup ("ContainedInRole");
   nr[2].aRole = CosRelationships::Role::_duplicate (role2);
 
- 
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow 
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     //       cout << "DegreeError exception!!!\n" << flush;
     //       cout << "Required degree is " << ex->required_degree << "\n" << flush;
     state_good = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     cout << "DuplicateRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i<(ex->culprits).length () ; i++) {
@@ -541,7 +570,7 @@ int main( int argc, char *argv[] )
     }
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     cout << "UnknownRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i< (ex->culprits).length (); i++) {
@@ -550,6 +579,8 @@ int main( int argc, char *argv[] )
     exception = TRUE;
     cout << "End of catch statement!\n" << flush;
   }
+#endif
+
   if (state_good) 
     cout << "ok.\n" << flush;
   else
@@ -565,17 +596,20 @@ int main( int argc, char *argv[] )
   nr[0].aRole = CosRelationships::Role::_duplicate (role1);
   nr[1].name = CORBA::string_dup ("ContainedInRole");
   nr[1].aRole = CosRelationships::Role::_duplicate (role1);  // ContainedInRole
- 
+
+#ifdef HAVE_EXCEPTIONS 
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     cout << "DegreeError exception!!!\n" << flush;
     cout << "Required degree is " << ex->required_degree << "\n" << flush;
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     cout << "DuplicateRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i<(ex->culprits).length () ; i++) {
@@ -583,7 +617,7 @@ int main( int argc, char *argv[] )
     }
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     cout << "UnknownRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i< (ex->culprits).length (); i++) {
@@ -592,7 +626,7 @@ int main( int argc, char *argv[] )
     exception = TRUE;
     cout << "End of catch statement!\n" << flush;
   }
-  catch (CosRelationships::RelationshipFactory::RoleTypeError &ex) {
+  catch (CosRelationships::RelationshipFactory::RoleTypeError_catch &ex) {
     //      cout << "RoleTypeError exception!!!\n" << flush;
     //      cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     //      for (int i=0; i< (ex->culprits).length (); i++) {
@@ -600,6 +634,7 @@ int main( int argc, char *argv[] )
     //      }
     state_good = TRUE;
   }
+#endif
 
   if (state_good)
     cout << "ok.\n" << flush;
@@ -617,16 +652,19 @@ int main( int argc, char *argv[] )
   nr[1].name = CORBA::string_dup ("ContainedInRole");  // will be twice
   nr[1].aRole = CosRelationships::Role::_duplicate (role2);
 
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     relship1 = CosContainment::Relationship::_narrow 
       (containment_factory->create (nr));
+#ifdef HAVE_EXCEPTIONS
   } 
-  catch (CosRelationships::RelationshipFactory::DegreeError &ex) {
+  catch (CosRelationships::RelationshipFactory::DegreeError_catch &ex) {
     cout << "DegreeError exception!!!\n" << flush;
     cout << "Required degree is " << ex->required_degree << "\n" << flush;
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::DuplicateRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::DuplicateRoleName_catch &ex) {
     cout << "DuplicateRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i<(ex->culprits).length () ; i++) {
@@ -634,7 +672,7 @@ int main( int argc, char *argv[] )
     }
     exception = TRUE;
   } 
-  catch (CosRelationships::RelationshipFactory::UnknownRoleName &ex) {
+  catch (CosRelationships::RelationshipFactory::UnknownRoleName_catch &ex) {
     cout << "UnknownRoleName exception!!!\n" << flush;
     cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     for (unsigned int i=0; i< (ex->culprits).length (); i++) {
@@ -643,7 +681,7 @@ int main( int argc, char *argv[] )
     exception = TRUE;
     cout << "End of catch statement!\n" << flush;
   }
-  catch (CosRelationships::RelationshipFactory::MaxCardinalityExceeded &ex) {
+  catch (CosRelationships::RelationshipFactory::MaxCardinalityExceeded_catch &ex) {
     //       cout << "MaxCardinalityExceeded exception!!!\n" << flush;
     //       cout << "ex->culprits.length () = " << (ex->culprits).length () << "\n" << flush;
     //       for (int i=0; i< (ex->culprits).length (); i++) {
@@ -651,7 +689,7 @@ int main( int argc, char *argv[] )
     //       }
     state_good = TRUE;
   }
-
+#endif
 
   if (state_good)
     cout << "ok.\n" << flush;
@@ -735,7 +773,10 @@ int main( int argc, char *argv[] )
 
   cout << "Checking Node::related_object () ..." << flush;
   exception = FALSE;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_text->related_object ();
     node_text->related_object ();
     if (!CORBA::is_nil (node_text->related_object ()))
@@ -743,12 +784,13 @@ int main( int argc, char *argv[] )
 	if ((Documents::Text::_narrow (node_text->related_object ()))
 	    ->name () != NULL)
 	  cout << "ok.\n";
-  } catch (CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     cout << "failed.\n";
-  } catch (CORBA::UserException& e) {
+  } catch (CORBA::UserException &e) {
     cout << "error.\n";
   }
-  
+#endif
   cout << "Checking Node::add_role () ..." << flush;
   CosGraphs::Node_var node_obr1;   
   CosGraphs::Node_var node_obr2;
@@ -756,15 +798,19 @@ int main( int argc, char *argv[] )
   CosGraphs::Node_var node_obr4;
   CosGraphs::Node_var node_obr5;
 
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_obr1 = node_factory->create_node (obr1);
     node_obr2 = node_factory->create_node (obr2);
     node_obr3 = node_factory->create_node (obr3);
     node_obr4 = node_factory->create_node (obr4);
     node_obr5 = node_factory->create_node (obr5);
-  } catch (::CORBA::Exception& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::Exception &e) {
     cout << "can't create nodes!!! " << flush;
   }
+#endif
   CosGraphs::Role_var contains;
   CosGraphs::Role_var containedin1;
   CosGraphs::Role_var containedin2;
@@ -773,7 +819,9 @@ int main( int argc, char *argv[] )
   CosGraphs::Role_var containedin4;
   CosGraphs::Role_var containedin5;
   
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     contains = CosGraphs::Role::_narrow 
       (contains_factory->create_role (node_text));
     containedin1 = CosGraphs::Role::_narrow
@@ -789,23 +837,29 @@ int main( int argc, char *argv[] )
     containedin5 = CosGraphs::Role::_narrow
       (containedin_factory->create_role (node_obr5));
 
-
-  } catch (CosRelationships::RoleFactory::NilRelatedObject& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CosRelationships::RoleFactory::NilRelatedObject_catch &e) {
     cout << "can't create roles - nil related object\n";
-  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError& e) {
+  } catch (CosRelationships::RoleFactory::RelatedObjectTypeError_catch &e) {
     cout << "can't create roles - related object type error\n";
-  } catch (::CORBA::SystemException& e) {
+  } catch (::CORBA::SystemException_catch &e) {
     cout << "can't create roles!!! system exception\n" << flush;
   }
-    
+#endif
 
   assert (!CORBA::is_nil (contains));
   exception = FALSE;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_text->add_role (contains);
-  } catch (::CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     exception = TRUE;
   }
+#endif
+
   if (node_text->roles_of_node ()->length () == 1 && !exception)
     cout << "ok.\n";
   else
@@ -815,13 +869,20 @@ int main( int argc, char *argv[] )
   cout << "Checking Node::roles_of_node () ..." << flush;
   exception = FALSE;
   CosGraphs::Node::Roles_var node_roles;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_roles = node_text->roles_of_node ();
     node_roles = node_text->roles_of_node ();
     node_roles = node_text->roles_of_node ();
-  } catch (CORBA::SystemException& e) {
+
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     exception = TRUE;
   }
+#endif
+
   if (node_roles->length () == 1 && !exception)
     cout << "ok.\n";
   else
@@ -829,14 +890,21 @@ int main( int argc, char *argv[] )
 
 
   cout << "Checking Node::remove_role () ..." << flush;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     ::CORBA::InterfaceDef_var type = contains->_get_interface ();
     node_text->remove_role (type);
-  } catch (CORBA::SystemException& e) {
+
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     cout << "system exception\n";
-  } catch (CORBA::UserException& e) {
+  } catch (CORBA::UserException &e) {
     exception = TRUE;
   }
+#endif
+
   if (node_text->roles_of_node ()->length () == 0 && !exception)
     cout << "ok.\n";
   else
@@ -866,7 +934,10 @@ int main( int argc, char *argv[] )
   state_good = TRUE;
   exception = FALSE;
   exception2 = FALSE;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_text->add_role (derived1_role);
     node_text->add_role (derived2_role);
     node_roles = node_text->roles_of_type (derived1_role_type);
@@ -894,12 +965,14 @@ int main( int argc, char *argv[] )
     // cleaning up
     node_text->remove_role (base_role_type);
 
-  } catch (CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     exception = TRUE;
-  } catch (CORBA::UserException& e) {
+  } catch (CORBA::UserException &e) {
     exception2 = TRUE;
   }
-  
+#endif  
+
   if (state_good && !exception2 && !exception)
     cout << "ok.\n";
   if (!state_good)
@@ -912,12 +985,19 @@ int main( int argc, char *argv[] )
 
   cout << "Checking Node::DuplicateRoleType exception ..." << flush;
   exception = FALSE;
+
+#ifdef HAVE_EXCEPTIONS
   try {
+#endif
     node_text->add_role (contains);
     node_text->add_role (contains);
-  } catch (CosGraphs::Node::DuplicateRoleType& e) {
+
+#ifdef HAVE_EXCEPTIONS
+  } catch (CosGraphs::Node::DuplicateRoleType_catch &e) {
     exception = TRUE;
   }
+#endif
+
   if (exception)
     cout << "ok.\n";
   else
@@ -928,31 +1008,47 @@ int main( int argc, char *argv[] )
   exception = FALSE;
   exception2 = FALSE;
   exception3 = FALSE;
+
+#ifdef HAVE_EXCEPTIONS
   try {
-    CORBA::InterfaceDef_var type = containedin1->_get_interface ();
+    CORBA::InterfaceDef_var type;
+#endif
+    type = containedin1->_get_interface ();
     node_text->remove_role (type);
-  } catch (CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     cout << "system exception\n";
-  } catch (CosGraphs::Node::NoSuchRole& e) {
+  } catch (CosGraphs::Node::NoSuchRole_catch &e) {
     exception = TRUE;
   }
+#endif
+#ifdef HAVE_EXCEPTIONS
   try {
-    CORBA::InterfaceDef_var type = contains->_get_interface ();
+    CORBA::InterfaceDef_var type;
+#endif
+    type = contains->_get_interface ();
     node_text->remove_role (type);
-  } catch (CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     cout << "system exception\n";
-  } catch (CosGraphs::Node::NoSuchRole& e) {
+  } catch (CosGraphs::Node::NoSuchRole_catch &e) {
     exception2 = TRUE;
   }
+#endif
+#ifdef HAVE_EXCEPTIONS
   try {
-    CORBA::InterfaceDef_var type = contains->_get_interface ();
+    CORBA::InterfaceDef_var type;
+#endif
+    type = contains->_get_interface ();
     node_text->remove_role (type);
-  } catch (CORBA::SystemException& e) {
+#ifdef HAVE_EXCEPTIONS
+  } catch (CORBA::SystemException_catch &e) {
     cout << "system exception\n";
-  } catch (CosGraphs::Node::NoSuchRole& e) {
+  } catch (CosGraphs::Node::NoSuchRole_catch &e) {
     exception3 = TRUE;
   }
-    
+#endif    
+
   if (exception && !exception2 && exception3) 
     cout << "ok.\n";
   else
