@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2003 by The Mico Team
+ *  Copyright (c) 1997-2006 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -455,9 +455,9 @@ void CodeGenCPPCommon::emitPrototypes( CORBA::Container_ptr in,
 {
   CORBA::ContainedSeq_var c;
 
+  bool b = use_rel_names (false);
   // Emit attributes
   c = in->contents (CORBA::dk_Attribute, 1);
-  bool b = use_rel_names (false);
   for( CORBA::ULong j = 0; j < c->length(); j++ ) {
     CORBA::AttributeDef_var attr = CORBA::AttributeDef::_narrow(c[j]);
     assert (!CORBA::is_nil(attr));
@@ -487,7 +487,6 @@ void CodeGenCPPCommon::emitPrototypes( CORBA::Container_ptr in,
       o << ";" << endl;
     }
   }
-  use_rel_names (b);
 
   if (c->length()) {
     o << endl;
@@ -575,6 +574,7 @@ void CodeGenCPPCommon::emitPrototypes( CORBA::Container_ptr in,
     o << endl;
   }
 
+  use_rel_names (b);
 }
 
 void
@@ -839,11 +839,11 @@ CodeGenCPPCommon::emit_Interface( CORBA::InterfaceDef_ptr in )
   case CORBA::dk_Interface:
     if (has_abstract_base && !has_concrete_base) {
       o << "virtual public CORBA::MixedBase";
-      if (bases->length()) o << "," << endl;
+      if (bases->length() || _params.reflection) o << "," << endl;
     }
     else if (!has_abstract_base && !has_concrete_base) {
       o << "virtual public CORBA::Object";
-      if (bases->length()) o << "," << endl;
+      if (bases->length() || _params.reflection) o << "," << endl;
     }
     break;
 
@@ -867,6 +867,11 @@ CodeGenCPPCommon::emit_Interface( CORBA::InterfaceDef_ptr in )
     break;
   }
 
+  if (in->def_kind() == CORBA::dk_Interface && _params.reflection) {
+    o << "virtual public Reflection::IFRProvider";
+    if (bases->length()) o << "," << endl;
+  }
+
   for (CORBA::ULong j1=0; j1<bases->length(); j1++) {
     CORBA::String_var base_name = bases[ j1 ]->absolute_name();
     o << "virtual public " << ID(base_name);
@@ -1006,6 +1011,9 @@ CodeGenCPPCommon::emit_Interface( CORBA::InterfaceDef_ptr in )
   }
 
   o << "virtual public " << className;
+  if (_params.reflection) {
+    o << "," << endl << "virtual public Reflection::IFRProvider" << _STUB;
+  }
   for( CORBA::ULong j2 = 0; j2 < bases->length(); j2++ ) {
     CORBA::String_var base_name = bases[ j2 ]->absolute_name();
     o << "," << endl << "virtual public " << ID(base_name) << _STUB;
@@ -1033,10 +1041,17 @@ CodeGenCPPCommon::emit_Interface( CORBA::InterfaceDef_ptr in )
       << className << _STUB << "_clp :" << indent << endl;
     o << "virtual public " << className << _STUB << "," << endl;
     
-    if (bases->length() == 0) {
+    if (_params.reflection && bases->length() == 0) {
+      o << "virtual public Reflection::IFRProvider" << _STUB << "_clp"
+	<< exdent << endl;
+    }
+    else if (bases->length() == 0) {
       o << "virtual public PortableServer::StubBase" << exdent << endl;
     }
     else {
+      if (_params.reflection) {
+	o << "virtual public Reflection::IFRProvider" << _STUB << "_clp," << endl;
+      }
       for (CORBA::ULong i2=0; i2<bases->length(); i2++) {
 	CORBA::String_var base_name = bases[i2]->absolute_name();
 	o << "virtual public " << ID(base_name) << _STUB << "_clp";
@@ -1064,28 +1079,6 @@ CodeGenCPPCommon::emit_Interface( CORBA::InterfaceDef_ptr in )
     o << exdent << BL_CLOSE_SEMI << endl;
     o << "#endif // MICO_CONF_NO_POA" << endl << endl;
   }
-
-  //-----SKELETON----------------------------------------------------
-  // Generate skeleton class for interface [18.3.1(6)], [18.4.5]
-  if (_params.boa && in->def_kind() == CORBA::dk_Interface) {
-    o << "class " << _params.class_export
-      << className << _SKEL << " :" << indent << endl;
-    o << "virtual public ";
-    o << "StaticMethodDispatcher," << endl;
-    o << "virtual public " << className << exdent << endl;
-    o << BL_OPEN;
-    o << "public:" << indent << endl;
-    o << className << _SKEL;
-    o << "( const CORBA::BOA::ReferenceData & = CORBA::BOA::ReferenceData() );";
-    o << endl;
-    o << "virtual ~" << className << _SKEL << "();" << endl;
-    o << className << _SKEL << "( CORBA::Object_ptr obj );" << endl;
-    o << "virtual bool dispatch( ";
-    o << "CORBA::StaticServerRequest_ptr";
-    o << " __req, CORBA::Environment &_env );" << endl;
-    o << className << "_ptr _this();" << exdent << endl << endl;
-    o << BL_CLOSE_SEMI << endl;
-  }
 }
 
 /*
@@ -1354,19 +1347,23 @@ void CodeGenCPPCommon::emit_Constant( CORBA::ConstantDef_ptr c )
   if( def_in->def_kind() == CORBA::dk_Repository ||
       def_in->def_kind() == CORBA::dk_Interface ||
       def_in->def_kind() == CORBA::dk_AbstractInterface ||
-      def_in->def_kind() == CORBA::dk_LocalInterface ) {
+      def_in->def_kind() == CORBA::dk_LocalInterface ||
+      def_in->def_kind() == CORBA::dk_Value ) {
     o << "static const ";
   } else {
     o << "const ";
   }
   CORBA::IDLType_var type = c->type_def();
   CORBA::TypeCode_var tc = type->type ();
-  emit_type_for_variable (type, manual);
-
-  if (tc->kind() == CORBA::tk_string
-      || tc->kind() == CORBA::tk_wstring) {
-    // special handling of string constants
-    o << " const";
+  // special handling of string/wstring constants
+  if (tc->unalias()->kind() == CORBA::tk_string) {
+      o << "char* const";
+  }
+  else if (tc->unalias()->kind() == CORBA::tk_wstring) {
+      o << "CORBA::WChar* const";
+  }
+  else {
+      emit_type_for_variable (type, manual);
   }
 
   o << " " << name;
@@ -1383,7 +1380,7 @@ void CodeGenCPPCommon::emit_Constant( CORBA::ConstantDef_ptr c )
       CORBA::Contained_var con = CORBA::Contained::_narrow (type);
       CORBA::String_var on = con->absolute_name ();
       string scoped_name = on.in();
-      CORBA::ULong i = scoped_name.find_last_of (":");
+      unsigned long i = scoped_name.find_last_of (":");
       if (i == 1 || i == string::npos) {
 	scoped_name = "";
       }
@@ -2138,8 +2135,9 @@ void CodeGenCPPCommon::emit_ValueBox( CORBA::ValueBoxDef_ptr vb )
     orig = ad->original_type_def ();
   }
 
-  CORBA::TypeCode_var tc = orig->type ();
-  tc = tc->unalias ();
+  CORBA::TypeCode_var orig_tc = orig->type ();
+  // kcg: unalias does not return duplicated TC!
+  CORBA::TypeCode_ptr tc = orig_tc->unalias ();
 
   switch (tc->kind()) {
   case CORBA::tk_short:
@@ -2679,10 +2677,16 @@ CodeGenCPPCommon::emit_poa_skel (CORBA::Container_ptr c)
 
     o << "class " << _params.class_export
       << prefix << className << " : ";
-    if (bc->length() == 0) {
+    if (_params.reflection && bc->length() == 0) {
+      o << "virtual public POA_Reflection::IFRProvider" << endl;
+    }
+    else if (bc->length() == 0) {
       o << "virtual public PortableServer::StaticImplementation" << endl;
     } else {
       o << indent << endl;
+      if (_params.reflection) {
+	o << "virtual public POA_Reflection::IFRProvider," << endl;
+      }
       for (CORBA::ULong i=0; i<bc->length(); i++) {
 	CORBA::String_var base_name = bc[i]->absolute_name();
 	string absBaseName = (const char *) ID (base_name);
@@ -2771,6 +2775,19 @@ CodeGenCPPCommon::emit_poa_skel (CORBA::Container_ptr c)
     o << "virtual CORBA::Object_ptr _make_stub"
       <<   " (PortableServer::POA_ptr, CORBA::Object_ptr);" << endl;
   }
+  if (_params.reflection) {
+    o << "virtual CORBA::Any * omg_get_ifr_metadata ()";
+    if (_params.throw_decl) {
+      o << " throw (Reflection::FormatNotSupported, CORBA::SystemException)";
+    }
+    o << ";" << endl;
+
+    o << "virtual char * omg_get_xml_metadata ()";
+    if (_params.throw_decl) {
+      o << " throw (Reflection::FormatNotSupported, CORBA::SystemException)";
+    }
+    o << ";" << endl;
+  }
   o << endl;
 
   /*
