@@ -32,7 +32,7 @@ protected:
   void emit_impl_h();
 
 public:
-  CodeGenCPPImpl( DB &db, IDLParam &params );
+  CodeGenCPPImpl( DB &db, IDLParam &params, CORBA::Container_ptr con );
 
 private:
   void emit_impl();
