@@ -36,12 +36,12 @@ private:
   void emit_contained( CORBA::IRObject_ptr obj );
   void emit_container( CORBA::Container_ptr obj );
   void emit_marshaller( CORBA::IRObject_ptr obj );
-  void emit_sii_stub_method( string &absClassName,
-			     string &dispatch_name,
+  void emit_sii_stub_method( std::string &absClassName,
+			     std::string &dispatch_name,
 			     const CORBA::OperationDescription &op,
 			     CORBA::IDLType_ptr result );
-  void emit_poa_stub_method( string &absClassName,
-			     string &dispatch_name,
+  void emit_poa_stub_method( std::string &absClassName,
+			     std::string &dispatch_name,
 			     const CORBA::OperationDescription &op,
 			     CORBA::IDLType_ptr result );
   void emit_Interface( CORBA::InterfaceDef_ptr in );
@@ -81,17 +81,17 @@ private:
   void emit_Value( CORBA::ValueDef_ptr v );
   void emit_ValueBox( CORBA::ValueBoxDef_ptr vb );
   void emit_ValueRekCheck( CORBA::IRObject_ptr obj,
-			   string, CORBA::ULong );
+			   std::string, CORBA::ULong );
   void emit_ValueReleaser( CORBA::IRObject_ptr obj,
-			   string, CORBA::ULong );
+			   std::string, CORBA::ULong );
 
-  void emit_var_def( const string &type,
+  void emit_var_def( const std::string &type,
 		     CORBA::Container_ptr scope,
-		     const string &name,
-		     const string &init );
+		     const std::string &name,
+		     const std::string &init );
   void emit_typecode_def( CORBA::Container_ptr scope,
-			  const string &abs,
-			  const string &name,
+			  const std::string &abs,
+			  const std::string &name,
 			  CORBA::TypeCode_ptr tc );
 public:
   CodeGenCPPStub( DB &db, IDLParam &params, CORBA::Container_ptr con );
