@@ -72,10 +72,10 @@ protected:
   DB*                         _db;
   IDLParam&                   _params;
 
-  set<string, less<string> >  _include_files;
+  std::set<std::string, std::less<std::string> >  _include_files;
 
-  string                      _name_prefix;
-  string                      _name_prefix_bak;
+  std::string                      _name_prefix;
+  std::string                      _name_prefix_bak;
   CORBA::Container_var        _current_scope;
   bool                        _emit_rel_names;
   
@@ -91,9 +91,9 @@ protected:
   void set_name_prefix( CORBA::Container_ptr c );
   void save_name_prefix();
   void restore_name_prefix();
-  void enter_scope( CORBA::Container_ptr c, string toplevel_prefix );
+  void enter_scope( CORBA::Container_ptr c, std::string toplevel_prefix );
   bool use_rel_names( bool );
-  void emit_rel_name( CORBA::Object_ptr obj, bool transform = false );
+  void emit_rel_name( CORBA::Object_ptr obj );
   void emit_type_name( CORBA::Object_ptr obj );
   void emit_mangled_name( const char *s );
   bool check_for_included_defn( CORBA::IRObject_ptr obj, bool emitinc = true );
@@ -116,21 +116,22 @@ protected:
   void emit_array_suffix( CORBA::IDLType_ptr t );
   void emit_array_slice_suffix( CORBA::IDLType_ptr t );
   CORBA::ULong compute_num_array_elem( CORBA::TypeCode_ptr tc );
-  void emit_assignment( const string& d, const string &s,
+  void emit_assignment( const std::string& d, const std::string &s,
 			CORBA::IDLType_ptr t );
   void emit_type_for_variable( CORBA::IDLType_ptr t, Storage s );
+  void emit_variable_initialization( CORBA::IDLType_ptr t, Storage s );
   bool emit_base_type( CORBA::IDLType_ptr t );
   void emit_array_marshalling( CORBA::ArrayDef_ptr arr,
 			       bool is_from,
 			       int level );
   bool is_union_case_defined( CORBA::UnionMemberSeq& mem,
 			      CORBA::Any &any );
-  string generate_union_default_case_label( CORBA::IDLType_ptr discr,
+  std::string generate_union_default_case_label( CORBA::IDLType_ptr discr,
 					    CORBA::UnionMemberSeq &mem );
   void emit_union_member_decl( CORBA::IDLType_ptr t,
 			       const char * name,
 			       bool as_pure_virtual );
-  void gen_mangled_name( string &str,
+  void gen_mangled_name( std::string &str,
 			 CORBA::IRObject_ptr obj,
 			 bool for_an_instance,
 			 bool first_call_to_gen = true );
@@ -141,26 +142,22 @@ protected:
 
   bool check_for_possible_circle_rek( CORBA::ValueDef_ptr v,
 				      CORBA::IRObject_ptr obj,
-				      vector<CORBA::IRObject_var> & );
+				      std::vector<CORBA::IRObject_var> & );
   bool check_for_possible_circle( CORBA::ValueDef_ptr v );
 
   bool contains_a_valuetype( CORBA::IRObject_ptr,
-			     vector<CORBA::IRObject_var> * = 0);
+			     std::vector<CORBA::IRObject_var> * = 0);
   bool check_simple_clp_call( const CORBA::OperationDescription & );
 
   bool is_var_inout( CORBA::IDLType_ptr );
   void emit_release( CORBA::IDLType_ptr, const char *var_name );
 
-  bool use_builtin_marshaller( CORBA::TypeCode_ptr, string &name );
+  bool use_builtin_marshaller( CORBA::TypeCode_ptr, std::string &name );
 
   CORBA::IDLType_ptr resolve_alias(CORBA::IDLType_ptr alias);
 
   bool is_marshallable (CORBA::IRObject_ptr);
 
-  // VC++ namespace-bug-workaround-helpers (tm)
-  string vc_transform (const string &);
-  string vc_emit_workaround (const string &prefix, const string &name);
-
 public:
   CodeGenCPPUtil( DB &db, IDLParam& params, CORBA::Container_ptr con );
 };
