@@ -36,7 +36,7 @@ class CodeGenCPP : virtual public CodeGenCPPCommon,
 {
 public:
   CodeGenCPP( DB &db, IDLParam &params, CORBA::Container_ptr con );
-  void emit( string &fnbase );
+  void emit( std::string &fnbase );
 };
 
 
