@@ -35,7 +35,7 @@ private:
 
   // afxTypeLib
   // used for TypeLib code
-  vector<CORBA::InterfaceDef_var> _coclasslist;
+  std::vector<CORBA::InterfaceDef_var> _coclasslist;
 
   // used for the scope of the objects
   char _midl_absolute_name[1000];
@@ -79,7 +79,7 @@ private:
   bool Is_Interface(CORBA::IDLType_ptr t);
   void emitInterfaceHeader();
   void emitHeader();
-  void emitTypeLib(string &fnbase);
+  void emitTypeLib(std::string &fnbase);
   const char* midl_absolute_name(const char *abs_name);
   char *recursive_container(CORBA::IDLType_ptr memb);
   void insert_guid();
@@ -89,8 +89,8 @@ private:
 
 public:
   CodeGenMIDL( DB &db, CORBA::Container_ptr con, bool emit_repoids );
-  void emit( string &fnbase );
-  string emit( CORBA::IRObject_ptr obj );
+  void emit( std::string &fnbase );
+  std::string emit( CORBA::IRObject_ptr obj );
 };
 
 
