@@ -23,10 +23,16 @@
 #ifndef __CODEGEN_H__
 #define __CODEGEN_H__
 
+#include <CORBA.h>
+
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iostream>
+#include <sstream>
+#else
 #include <iostream.h>
 #include <strstream.h>
+#endif
 
-#include <CORBA.h>
 #include <mico/template_impl.h>
 
 #include "dep.h"
@@ -42,12 +48,12 @@ enum OutputFormatting {
 };
 
 
-#ifdef _WINDOWS
+#if defined(_WIN32) && defined(_MSC_VER)
 MICO_MAKE_WRAPPER(MICO_WCharWrapper,MICO_WChar);
 #endif
 
 
-typedef ostream& (*endlnfp)(ostream &);
+typedef std::ostream& (*endlnfp)(std::ostream &);
 
 class Output;
 
@@ -59,8 +65,11 @@ private:
   int         _indent;
   int         _current_indent;
   bool        _bofl;   // Beginning of line
-  // changed for Cygnus CDK
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+  std::ostringstream *_ostr;
+#else
   ostrstream  *_ostr;
+#endif
   void checkBofL();
 
 public:
@@ -69,7 +78,7 @@ public:
   void enterLevel();
   void leaveLevel();
   OutputStream &operator<<( const char *s );
-  OutputStream &operator<<( const string &str );
+  OutputStream &operator<<( const std::string &str );
   OutputStream &operator<<( const CORBA::WChar *s );
 #if SIZEOF_LONG == 4
   // on 64 bit systems CORBA::Long is int
@@ -85,7 +94,7 @@ public:
   OutputStream &operator<<( CORBA::Short s );
   OutputStream &operator<<( CORBA::UShort us );
   OutputStream &operator<<( CORBA::Char c );
-#ifdef _WINDOWS
+#if defined(_WIN32) && defined(_MSC_VER)
   OutputStream &operator<<( MICO_WCharWrapper c );
 #else
   OutputStream &operator<<( CORBA::WChar c );
@@ -103,11 +112,11 @@ private:
   
   int           _current_stream;
   OutputStream* _streams[ MaxStreams ];
-  ostream*      _ostr;
+  std::ostream*      _ostr;
 public:
   Output();
   ~Output();
-  void start_output( ostream &o, int indent = 2 );
+  void start_output( std::ostream &o, int indent = 2 );
   void stop_output();
   void free_streams();
   void save_streams( Output &o );
@@ -116,7 +125,7 @@ public:
   void enterLevel();
   void leaveLevel();
   Output &operator<<( const char *s );
-  Output &operator<<( const string &str );
+  Output &operator<<( const std::string &str );
   Output &operator<<( const CORBA::WChar *s );
 #if SIZEOF_LONG == 4
   // on 64 bit systems CORBA::Long is int
@@ -132,7 +141,7 @@ public:
   Output &operator<<( CORBA::Short s );
   Output &operator<<( CORBA::UShort us );
   Output &operator<<( CORBA::Char c );
-#ifdef _WINDOWS
+#if defined(_WIN32) && defined(_MSC_VER)
   Output &operator<<( MICO_WCharWrapper c );
 #else
   Output &operator<<( CORBA::WChar c );
@@ -160,7 +169,7 @@ protected:
 public:
   CodeGen( CORBA::Container_ptr con );
   virtual ~CodeGen ();
-  virtual void emit( string &fnbase ) = 0;
+  virtual void emit( std::string &fnbase ) = 0;
 };
 
 
