@@ -20,9 +20,22 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "idl_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #include "const.h"
 #include "error.h"
 
+#endif // FAST_PCH
+
+
+using namespace std;
 
 //-- Const --------------------------------------------------------------
 
@@ -216,22 +229,22 @@ void Const::coercion_error( CORBA::TypeCode_ptr from, CORBA::TypeCode_ptr to )
   const char* from_str = kind [from->kind()];
   
   if (from->kind() == CORBA::tk_string) {
-    sprintf (from_buf, "string<%d>", from->length());
+    sprintf (from_buf, "string<%d>", (unsigned int)from->length());
     from_str = from_buf;
   }
   
   if (from->kind() == CORBA::tk_wstring) {
-    sprintf (from_buf, "wstring<%d>", from->length());
+    sprintf (from_buf, "wstring<%d>", (unsigned int)from->length());
     from_str = from_buf;
   }
   
   if (to->kind() == CORBA::tk_string) {
-    sprintf (to_buf, "string<%d>", to->length());
+    sprintf (to_buf, "string<%d>", (unsigned int)to->length());
     to_str = to_buf;
   }
   
   if (to->kind() == CORBA::tk_wstring) {
-    sprintf (to_buf, "wstring<%d>", to->length());
+    sprintf (to_buf, "wstring<%d>", (unsigned int)to->length());
     to_str = to_buf;
   }
   
