@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2006 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -203,16 +203,18 @@ IDLDep::is_circular_dep( Dep* from, Dep* to )
 }
 
 void
-IDLDep::create_dep( Dep* from, Dep* to )
+IDLDep::create_dep( Dep* from, Dep* to, bool parent_dependency )
 {
   // if there is a circular dependency (which would occur for
   // recursive data structures), we don't need to register a dependency
-  if( is_circular_dep( from, to ) ) {
-      
+  if( !parent_dependency && is_circular_dep( from, to ) ) {
     // Actually, if "to" denotes an InterfaceDef, then we had a
     // forward declaration before "from" was defined. Therefore
     // we need to add this dependency to the forward declaration
     // at this time.
+    // kcg: the only difference is when looking for dependency
+    // for inherited parents, then we can not use forwarded declaration
+    // but need to find fully defined parent
     if( !CORBA::is_nil( to->obj ) &&
 	(to->obj->def_kind() == CORBA::dk_Interface ||
 	 to->obj->def_kind() == CORBA::dk_AbstractInterface ||
@@ -462,7 +464,7 @@ IDLDep::dep_Alias( CORBA::AliasDef_ptr a )
   create_iface_dep( from );
 
   CORBA::IDLType_var orig = a->original_type_def();
-  Dep* to = locate_dep( orig );
+  Dep* to = locate_dep( orig, true );
 
   create_dep( from, to );
 }
@@ -478,7 +480,7 @@ IDLDep::dep_Interface( CORBA::InterfaceDef_ptr in )
   CORBA::InterfaceDefSeq_var bases = in->base_interfaces();
   for( CORBA::ULong i0 = 0; i0 < bases->length(); i0++ ) {
     Dep* to = locate_dep( bases[ i0 ], true, true );
-    create_dep( from, to );
+    create_dep( from, to, true );
   }
 
   // set dependencies for local declarations
@@ -567,19 +569,19 @@ IDLDep::dep_Value( CORBA::ValueDef_ptr vb )
   CORBA::InterfaceDefSeq_var supported_interfaces = vb->supported_interfaces();
   for (CORBA::ULong i2=0; i2<supported_interfaces->length(); i2++) {
     Dep * to = locate_dep (supported_interfaces[i2], true, true);
-    create_dep (from, to);
+    create_dep (from, to, true);
   }
 
   CORBA::ValueDef_var base_value = vb->base_value ();
   if (!CORBA::is_nil (base_value)) {
     Dep * to = locate_dep (base_value, true, true);
-    create_dep (from, to);
+    create_dep (from, to, true);
   }
 
   CORBA::ValueDefSeq_var abv = vb->abstract_base_values ();
   for (CORBA::ULong i0=0; i0<abv->length(); i0++) {
     Dep * to = locate_dep (abv[i0], true, true);
-    create_dep (from, to);
+    create_dep (from, to, true);
   }
 
   // set dependencies for types in initializer list
