@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2005 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -544,9 +544,26 @@ IDLParser::collectImport (CORBA::Container_ptr con, ParseNode *node)
 #endif // _WIN32
 
   cmd += _params->cpp_options;
-  cmd += " -I";
-  cmd += ABSEXECDIR;
-  cmd += "/include ";
+  cmd += ' ';
+
+  string includepath;
+  if (_params->base_dir.empty()) {
+    includepath = ABSEXECDIR;
+    if (!includepath.empty() && includepath[includepath.length() - 1] != '/')
+      includepath += '/';
+  } else {
+    includepath = _params->base_dir;
+  }
+  includepath += "include/";
+  string micopath = includepath + "mico/";
+
+  cmd += "-isystem ";
+  cmd += includepath;
+  cmd += ' ';
+  cmd += " -isystem ";
+  cmd += micopath;
+  cmd += ' ';
+
   cmd += absolute_file_name;
 
   FILE * inp_file = OSMisc::popen (cmd.c_str(), "r");
@@ -900,7 +917,7 @@ void IDLParser::collectConstDcl( CORBA::Container_ptr con, ParseNode *node )
   case CORBA::tk_enum:
     {
       string scoped_name = collectScopedName (node->getBranch(2));
-      CORBA::ULong i = scoped_name.find_last_of (":");
+      unsigned long i = scoped_name.find_last_of (":");
 
       if (i != string::npos) {
 	scoped_name = scoped_name.substr (i+1);
