@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2003 by The Mico Team
+ *  Copyright (c) 1997-2008 by The Mico Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -79,9 +79,11 @@ IDLParam::set_defaults()
   cpp = "\"" + p + cpp + "\"";
 #endif // _WIN32
 
+  base_dir = "";
   cpp_suffix = "cc";
+  hh_prefix = "";
   hh_suffix = "h";
-  relative_paths = false;
+  use_quotes = false;
   feed_ir = false;
   feed_included_defs = true;
   codegen_cpp = false;
@@ -114,8 +116,11 @@ IDLParam::set_defaults()
   gen_full_dispatcher = false;
   throw_decl = false;
   idl3toidl2 = false;
-  include_prefix = false;
-  i_prefix = "";
+  no_path_in_include = false;
+  reflection = false;
+  vc_sequence_reference_bug_workaround = false;
+  i_prefixes.clear();
+  i_postfixes.clear();
   output_dir = "";
   skel_suffix = "_skel";
   dll_def_prefix = "";
@@ -144,8 +149,10 @@ IDLParam::parse_params()
   opts["--c++-suffix"]            = "arg-expected";
   opts["--c++-impl"]              = "";
   opts["--c++-skel"]              = "";
+  opts["--hh-prefix"]             = "arg-expected";
   opts["--hh-suffix"]             = "arg-expected";
-  opts["--relative-paths"]        = "";
+  opts["--use-quotes"]            = "";
+  opts["--relative-paths"]            = "";
   opts["--emit-repoids"]          = "";
   opts["--do-not-query-server-for-narrow"] = "";
   opts["--repo-id"]               = "arg-expected";
@@ -183,10 +190,17 @@ IDLParam::parse_params()
   opts["--no-wsi-wsdl"]           = "";
   opts["--cpp"]                   = "arg-expected";
   opts["--include-prefix"]        = "arg-expected";
+  opts["--include-postfix"]       = "arg-expected";
+  opts["--no-paths"]              = "";
   opts["--output-dir"]       	  = "arg-expected";
   opts["--skel-suffix"]       	  = "arg-expected";
+  opts["--reflection"]            = "";
+  opts["--no-reflection"]         = "";
+  opts["--vc-sequence-reference-bug-workaround"] = "";
+  opts["--no-vc-sequence-reference-bug-workaround"] = "";
   
   // Preprocessor options
+  opts["-B"]                      = "arg-expected";
   opts["-I"]                      = "arg-expected";
   opts["-D"]                      = "arg-expected";
   opts["-E"]                      = "";
@@ -209,17 +223,38 @@ IDLParam::parse_params()
     string arg = (*i).first;
     string val = (*i).second;
 
-    if (arg == "-I") {
-      // remove ./'s
+    if (arg == "-B") {
+      // remove ./'s, attach trailing /
       int pos;
       while ((pos = val.find ("/./")) >= 0)
 	val.replace (pos, 2, "", 0);
       if (val.find ("./") == 0)
 	val.replace (0, 2, "", 0);
+      if (val == ".")
+        val.erase();
+      else if (!val.empty() && val[val.length() - 1] != '/')
+        val += "/";
+
+      base_dir = val;
+    } else if (arg == "-I") {
+      // remove ./'s, attach trailing /
+      int pos;
+      while ((pos = val.find ("/./")) >= 0)
+	val.replace (pos, 2, "", 0);
+      if (val.find ("./") == 0)
+	val.replace (0, 2, "", 0);
+      if (val == ".")
+        val.erase();
+      else if (!val.empty() && val[val.length() - 1] != '/')
+        val += "/";
 
       cpp_options += " ";
-      cpp_options += arg + val;
+      cpp_options += arg;
+      cpp_options += val.empty() ? string(".") : val;
+      // --include-prefix and --include-postfix refer to inc_paths.back()
       inc_paths.push_back (val);
+      // default include path substitution is empty
+      i_prefixes[val] = string();
     } else if (arg == "-D") {
       cpp_options += " ";
       cpp_options += arg + val;
@@ -280,13 +315,36 @@ IDLParam::parse_params()
     } else if( arg == "--output-dir" ) {
       output_dir = val;
       if ( !output_dir.empty() && output_dir[output_dir.length() - 1] != '/' )
-        output_dir += "/";
+        output_dir += '/';
     } else if( arg == "--skel-suffix" ) {
       skel_suffix = val;
+    } else if( arg == "--hh-prefix" ) {
+      // remove ./'s, attach trailing /
+      int pos;
+      while ((pos = val.find ("/./")) >= 0)
+	val.replace (pos, 2, "", 0);
+      if (val.find ("./") == 0)
+	val.replace (0, 2, "", 0);
+      if (val == ".")
+        val.erase();
+      else if (!val.empty() && val[val.length() - 1] != '/')
+        val += "/";
+
+      hh_prefix = val;
     } else if( arg == "--hh-suffix" ) {
       hh_suffix = val;
+    } else if( arg == "--use-quotes" ) {
+      use_quotes = true;
+    } else if( arg == "--no-paths" ) {
+      no_path_in_include = true;
     } else if( arg == "--relative-paths" ) {
-      relative_paths = true;
+      cerr << endl
+	   << "WARNING: generation of include directives relative to default and" << endl
+	   << "WARNING: user-defined include paths is now the standard mode. Please" << endl
+	   << "WARNING: refer to the manual pages to learn about new options for" << endl
+	   << "WARNING: modifying the generation of include directives." << endl
+	   << "WARNING: To avoid this warning please remove ``--relative-paths'' parameter" << endl
+	   << "WARNING: from the IDL compiler command-line." << endl;
     } else if (arg == "--emit-repoids") {
       emit_repoids = true;
     } else if( arg == "--do-not-query-server-for-narrow" ) {
@@ -300,18 +358,12 @@ IDLParam::parse_params()
     } else if (arg == "--ifdef-prefix") {
       ifdef_prefix = val;
     } else if (arg == "--boa") {
-      boa = true;
-      cerr << "WARNING: BOA is long time deprecated feature which will probably be removed" << endl
-	   << "WARNING: in some of the future MICO releases! Please consider to rewrite your application" << endl
-	   << "WARNING: to use POA instead of BOA and then please remove ``--boa'' parameter" << endl
-	   << "WARNING: from the IDL compiler command-line." << endl;
-#ifdef HAVE_THREADS
-      cerr << endl
-	   << "WARNING2: Please note that MICO BOA implementation is not multi-threaded safe" << endl
-	   << "WARNING2: and so there is a big chance that your BOA-based application" << endl
-	   << "WARNING2: will not be stable." << endl << endl;
-#endif // HAVE_THREADS
+	cerr << "error: --boa option is no longer supported" << endl
+	     << "       (if you need BOA support, please use MICO release older than 2.3.12)" << endl;
+	exit(1);
     } else if (arg == "--no-boa") {
+	cerr << "warning: --no-boa option is ignored" << endl
+	     << "         (MICO release later than 2.3.11 does not support BOA anymore)" << endl;
       boa = false;
     } else if (arg == "--poa") {
       poa = true;
@@ -359,6 +411,14 @@ IDLParam::parse_params()
       throw_decl = false;
     } else if (arg == "--idl3toidl2") {
       idl3toidl2 = true;
+    } else if (arg == "--reflection") {
+      reflection = true;
+    } else if (arg == "--no-reflection") {
+      reflection = false;
+    } else if (arg == "--vc-sequence-reference-bug-workaround") {
+      vc_sequence_reference_bug_workaround = true;
+    } else if (arg == "--no-vc-sequence-reference-bug-workaround") {
+      vc_sequence_reference_bug_workaround = false;
     } else if (arg == "--missing-nscorba") {
       missing_nscorba = true;
     } else if (arg == "--not-missing-nscorba") {
@@ -374,8 +434,35 @@ IDLParam::parse_params()
     } else if( arg == "--cpp" ) {
       cpp = val;
     } else if (arg == "--include-prefix") {
-      include_prefix = true;
-      i_prefix = val;
+      // remove ./'s, attach trailing /
+      int pos;
+      while ((pos = val.find ("/./")) >= 0)
+	val.replace (pos, 2, "", 0);
+      if (val.find ("./") == 0)
+	val.replace (0, 2, "", 0);
+      if (val == ".")
+        val.erase();
+      else if (!val.empty() && val[val.length() - 1] != '/')
+        val += "/";
+
+      if (inc_paths.empty())
+	usage();
+      i_prefixes[inc_paths.back()] = val;
+    } else if (arg == "--include-postfix") {
+      // remove ./'s, attach trailing /
+      int pos;
+      while ((pos = val.find ("/./")) >= 0)
+	val.replace (pos, 2, "", 0);
+      if (val.find ("./") == 0)
+	val.replace (0, 2, "", 0);
+      if (val == ".")
+        val.erase();
+      else if (!val.empty() && val[val.length() - 1] != '/')
+        val += "/";
+
+      if (inc_paths.empty())
+	usage();
+      i_postfixes[inc_paths.back()] = val;
     } else if (arg == "--version") {
       cout << "MICO Version " << MICO_VERSION << endl;
       exit( 0 );
@@ -485,8 +572,10 @@ IDLParam::usage()
   cerr << "    --c++-skel" << endl;
   cerr << "    --codegen-wsdl" << endl;
   cerr << "    --no-codegen-wsdl" << endl;
+  cerr << "    --hh-prefix <hh-prefix>" << endl;
   cerr << "    --hh-suffix <filename-suffix>" << endl;
-  cerr << "    --relative-paths" << endl;
+  cerr << "    --use-quotes" << endl;
+  cerr << "    --no-paths" << endl;
   cerr << "    --emit-repoids" << endl;
   cerr << "    --do-not-query-server-for-narrow" << endl;
   cerr << "    --repo-id <repository-id>" << endl;
@@ -495,8 +584,6 @@ IDLParam::usage()
   cerr << "    --ifdef-prefix <prefix>" << endl;
   cerr << "    --poa" << endl;
   cerr << "    --no-poa" << endl;
-  cerr << "    --boa    --    (deprecated)" << endl;
-  cerr << "    --no-boa" << endl;
   cerr << "    --no-poa-ties" << endl;
   cerr << "    --no-poa-stubs" << endl;
   cerr << "    --pseudo" << endl;
@@ -514,6 +601,11 @@ IDLParam::usage()
   cerr << "    --wsi-wsdl" << endl;
   cerr << "    --no-wsi-wsdl" << endl;
   cerr << "    --include-prefix <include-prefix>" << endl;
+  cerr << "    --include-postfix <include-postfix>" << endl;
+  cerr << "    --reflection" << endl;
+  cerr << "    --no-reflection" << endl;
+  cerr << "    --vc-sequence-reference-bug-workaround" << endl;
+  cerr << "    --no-vc-sequence-reference-bug-workaround" << endl;
   exit( 1 );
 }
 
@@ -558,6 +650,14 @@ IDLParam::config()
   cout << "system supplied" << endl;
 #endif
 
+  cout << "Messaging support......: ";
+#ifdef USE_MESSAGING
+  cout << "yes";
+#else // USE_MESSAGING
+  cout << "no";
+#endif // USE_MESSAGING
+  cout << endl;
+
   cout << "Security support.......: ";
 #ifdef HAVE_SSL
   cout << "TLS/SSL";
@@ -567,6 +667,9 @@ IDLParam::config()
 #ifdef USE_CSL2
   cout << ", CSL2";
 #endif // USE_CSL2
+#ifdef USE_SL3
+  cout << ", SL3";
+#endif // USE_SL3
 #else // HAVE_SSL
   cout << "no";
 #endif
@@ -610,5 +713,80 @@ IDLParam::config()
   cout << ")" << endl;
 #endif // HAVE_THREADS
 
+  cout << "threading policies.....: ";
+#ifdef THREADING_POLICIES
+  cout << "yes" << endl;
+#else
+  cout << "no" << endl;
+#endif
+
   exit (0);
 }
+
+// rewrite path according to --no-paths / --include-prefix / --include-postfix
+string
+IDLParam::rewrite_include_path(string fname) const
+{
+  if (no_path_in_include) {
+    string::size_type last_slash = fname.rfind('/');
+    if (string::npos == last_slash) {
+      return fname;
+    } else if (fname.length() - 1 <= last_slash) {
+      return string();
+    } else {
+      return fname.substr(last_slash + 1);
+    }
+    return fname;
+  }
+
+  // remove ./'s
+  int pos;
+  while ((pos = fname.find ("/./")) >= 0)
+    fname.replace (pos, 2, "", 0);
+  if (fname.find ("./") == 0)
+    fname.replace (0, 2, "", 0);
+
+  bool relativeFname = fname[0] != '/';
+
+  map<string, string, std::less<std::string> >::const_iterator
+    i_prefixes_match = i_prefixes.end();
+  map<string, string, std::less<std::string> >::const_iterator
+    i_postfixes_match = i_postfixes.end();
+  for (map<string, string, std::less<std::string> >::const_iterator prefix_it = i_prefixes.begin();
+    prefix_it != i_prefixes.end(); ++prefix_it) {
+    if (fname.find(prefix_it->first) == 0) {
+      if (i_prefixes.end() == i_prefixes_match ||
+        prefix_it->first.length() > i_prefixes_match->first.length()) {
+        i_prefixes_match = prefix_it;
+      }
+    }
+  }
+  for (map<string, string, std::less<std::string> >::const_iterator postfix_it = i_postfixes.begin();
+    postfix_it != i_postfixes.end(); ++postfix_it) {
+    if (fname.find(postfix_it->first) == 0) {
+      if (i_postfixes.end() == i_postfixes_match ||
+        postfix_it->first.length() > i_postfixes_match->first.length()) {
+        i_postfixes_match = postfix_it;
+      }
+    }
+  }
+  if (i_prefixes.end() != i_prefixes_match &&
+    (i_prefixes_match->first.length() || relativeFname)) {
+    fname = fname.substr(i_prefixes_match->first.length());
+    while (fname[0] == '/') {
+      fname = fname.substr (1);
+    }
+    fname.insert(0, i_prefixes_match->second);
+  }
+  if (i_postfixes.end() != i_postfixes_match &&
+    (i_postfixes_match->first.length() || relativeFname)) {
+    std::string::size_type last_slash = fname.rfind('/');
+    if (last_slash == std::string::npos) {
+      last_slash = 0;
+    } else {
+      ++last_slash;
+    }
+    fname.insert(last_slash, i_postfixes_match->second);
+  }
+  return fname;
+}
