@@ -1,7 +1,7 @@
 // -*- c++ -*-
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2005 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -39,7 +39,8 @@ public:
 	CORBA::Octet *, CORBA::ULong, const CORBA::MultiComponent &,
         CORBA::UShort version = 0x0100) const;
     CORBA::Boolean is_local () const;
-    
+    CORBA::Boolean is_here () const;
+
     CORBA::Address *clone () const;
     
     CORBA::Long compare (const CORBA::Address &) const;
@@ -74,6 +75,11 @@ private:
 
     CORBA::Boolean resolve_ip () const;
     CORBA::Boolean resolve_host () const;
+    // kcg: temporary lock for gethostbyname/gethostbyaddr
+    // calls serialization. InetAddress and Transports
+    // should be rewritten to use getaddrinfo/getnameinfo
+    // functions
+    static MICOMT::Mutex S_netdb_lock_;
 public:
     InetAddress (struct sockaddr_in &sin, Family = STREAM);
     InetAddress (const char *host = NULL, CORBA::UShort port = 0,
@@ -90,6 +96,7 @@ public:
 	CORBA::Octet *, CORBA::ULong, const CORBA::MultiComponent &,
         CORBA::UShort version = 0x0100) const;
     CORBA::Boolean is_local () const;
+    CORBA::Boolean is_here () const;
     
     CORBA::Address *clone () const;
     
@@ -147,6 +154,7 @@ public:
 	CORBA::Octet *, CORBA::ULong, const CORBA::MultiComponent &,
         CORBA::UShort version = 0x0100) const;
     CORBA::Boolean is_local () const;
+    CORBA::Boolean is_here () const;
     
     CORBA::Address *clone () const;
     
