@@ -1,6 +1,6 @@
 // -*- c++ -*-
 /*
- *  MICO --- a free CORBA implementation
+ *  MICO --- an Open Source CORBA implementation
  *  Copyright (C) 1998 Frank Pilhofer
  *
  *  This library is free software; you can redistribute it and/or
@@ -17,21 +17,21 @@
  *  License along with this library; if not, write to the Free
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  Send comments and/or bug reports to:
- *                 mico@informatik.uni-frankfurt.de
+ *  For more information, visit the MICO Home Page at
+ *  http://www.mico.org/
  */
 
 #if !defined(__POA_BASE_H__) || defined(MICO_NO_TOPLEVEL_MODULES)
 #define __POA_BASE_H__
 
 #ifndef MICO_NO_TOPLEVEL_MODULES
-MICO_NAMESPACE_DECL PortableServer {
+namespace PortableServer {
 #endif
 
 #if !defined(MICO_NO_TOPLEVEL_MODULES) || defined(MICO_MODULE_PortableServer)
 
-MICO_EXPORT_VAR_DECL POA * _the_root_poa;
-MICO_EXPORT_VAR_DECL Current * _the_poa_current;
+extern MICO_EXPORT POA * _the_root_poa;
+extern MICO_EXPORT Current * _the_poa_current;
 
 class ServantBase
 {
@@ -41,13 +41,14 @@ public:
   virtual POA_ptr _default_POA();
   virtual CORBA::Boolean _is_a (const char *);
   virtual CORBA::Boolean _non_existent ();
+  virtual CORBA::Object_ptr _get_component ();
   virtual CORBA::InterfaceDef_ptr _get_interface () = 0;
 
   // begin-mico-extension (moved up from DynamicImplementation)
   CORBA::InterfaceDef_ptr _get_interface (const char *repoid);
   CORBA::Object_ptr _this ();
-  virtual CORBA::RepositoryId _primary_interface (const ObjectId &,
-						  POA_ptr) = 0;
+  virtual char * _primary_interface (const ObjectId &,
+				     POA_ptr) = 0;
   // end-mico-extension
 
   virtual void _add_ref ();
@@ -59,7 +60,7 @@ public:
   virtual CORBA::Object_ptr _make_stub (POA_ptr, CORBA::Object_ptr);
   virtual CORBA::ServerRequestBase_ptr make_request (CORBA::ORBRequest *,
 						     CORBA::Object_ptr,
-						     CORBA::ULong,
+						     CORBA::ORBMsgId,
 						     CORBA::ObjectAdapter *,
 						     CORBA::Principal_ptr) = 0;
   virtual void doinvoke (CORBA::ServerRequestBase_ptr) = 0;
@@ -75,8 +76,45 @@ protected:
   POA_ptr _my_poa;
 };
 
+// final overriders for methods defined in POA skeletons to avoid
+// ambiquities when inheriting from multiple POA skeletons 
+#define MICO_MAKE_POA_OVERRIDE_METHODS(scope,class)                              \
+  scope::class##_ptr _this ()                                                    \
+  {                                                                              \
+      return this->POA_##scope::class::_this();                      \
+  }                                                                              \
+  void invoke (CORBA::StaticServerRequest_ptr ssr)                               \
+  {                                                                              \
+      this->POA_##scope::class::invoke(ssr);                         \
+  }                                                                              \
+  CORBA::Boolean _is_a (const char *repoid)                                      \
+  {                                                                              \
+      return this->POA_##scope::class::_is_a(repoid);                \
+  }                                                                              \
+  CORBA::InterfaceDef_ptr _get_interface ()                                      \
+  {                                                                              \
+      return this->POA_##scope::class::_get_interface();             \
+  }                                                                              \
+  CORBA::RepositoryId _primary_interface (                                       \
+      const PortableServer::ObjectId &oid,                                       \
+      PortableServer::POA_ptr poa)                                               \
+  {                                                                              \
+      return this->POA_##scope::class::_primary_interface(oid, poa); \
+  }                                                                              \
+  void * _narrow_helper (const char *repoid)                                     \
+  {                                                                              \
+      return this->POA_##scope::class::_narrow_helper(repoid);       \
+  }                                                                              \
+  CORBA::Object_ptr _make_stub (                                                 \
+      PortableServer::POA_ptr poa,                                               \
+      CORBA::Object_ptr obj)                                                     \
+  {                                                                              \
+      return this->POA_##scope::class::_make_stub(poa, obj);         \
+  }
+ 
 class RefCountServantBase : virtual public ServantBase
 {
+  MICOMT::Mutex _ref_lock;
 public:
   virtual ~RefCountServantBase ();
 
@@ -123,8 +161,8 @@ public:
 
   CORBA::Object_ptr _this ();
   virtual void invoke (CORBA::ServerRequest_ptr) = 0;
-  virtual CORBA::RepositoryId _primary_interface (const ObjectId &,
-						  POA_ptr) = 0;
+  virtual char * _primary_interface (const ObjectId &,
+				     POA_ptr) = 0;
 
   /*
    * Default implementation uses _primary_interface
@@ -136,7 +174,7 @@ public:
   // begin-mico-extension
   CORBA::ServerRequestBase_ptr make_request (CORBA::ORBRequest *,
 					     CORBA::Object_ptr,
-					     CORBA::ULong,
+					     CORBA::ORBMsgId,
 					     CORBA::ObjectAdapter *,
 					     CORBA::Principal_ptr);
   void doinvoke (CORBA::ServerRequestBase_ptr);
@@ -151,7 +189,7 @@ public:
   virtual void invoke (CORBA::StaticServerRequest_ptr) = 0;
   CORBA::ServerRequestBase_ptr make_request (CORBA::ORBRequest *,
 					     CORBA::Object_ptr,
-					     CORBA::ULong,
+					     CORBA::ORBMsgId,
 					     CORBA::ObjectAdapter *,
 					     CORBA::Principal_ptr);
   virtual void doinvoke (CORBA::ServerRequestBase_ptr);
@@ -177,15 +215,15 @@ private:
 };
 // end-mico-extension
 
-MICO_EXPORT_FCT_DECL char *         ObjectId_to_string  (const ObjectId &);
-MICO_EXPORT_FCT_DECL CORBA::WChar * ObjectId_to_wstring (const ObjectId &);
-MICO_EXPORT_FCT_DECL ObjectId *     string_to_ObjectId  (const char *);
-MICO_EXPORT_FCT_DECL ObjectId *     wstring_to_ObjectId (const CORBA::WChar *);
+extern char *         ObjectId_to_string  (const ObjectId &);
+extern CORBA::WChar * ObjectId_to_wstring (const ObjectId &);
+extern ObjectId *     string_to_ObjectId  (const char *);
+extern ObjectId *     wstring_to_ObjectId (const CORBA::WChar *);
 
 #endif // !defined(MICO_NO_TOPLEVEL_MODULES) || defined(MICO_MODULE_PortableServer)
 
 #ifndef MICO_NO_TOPLEVEL_MODULES
-} MICO_NAMESPACE_END_DECL
+} 
 #endif
 
 /*
