@@ -55,7 +55,7 @@ class istrstream : public virtual istream {
 public:
 	istrstream (const char*)
 	{
-		NOT_IMPLEMENTED;
+		MICO_NOT_IMPLEMENTED;
 	}
 };
 
