@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2005 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -45,6 +45,12 @@
 
 using namespace std;
 
+
+//
+// static data initialization
+//
+MICOMT::Mutex MICO::InetAddress::S_netdb_lock_;
+
 /************************* misc dtors *******************************/
 
 
@@ -172,6 +178,12 @@ MICO::LocalAddress::is_local () const
     return TRUE;
 }
 
+CORBA::Boolean
+MICO::LocalAddress::is_here () const
+{
+    return TRUE;
+}
+
 CORBA::Address *
 MICO::LocalAddress::clone () const
 {
@@ -269,14 +281,23 @@ MICO::InetAddress::resolve_ip () const
 			   (CORBA::Octet *)&addr + sizeof (CORBA::ULong));
 	return TRUE;
     }
-
+#ifndef HAVE_THREADS
     struct hostent *hent = ::gethostbyname ((char *)_host.c_str());
+#else // HAVE_THREADS
+    struct hostent* hent = NULL;
+    {
+        MICOMT::AutoLock lock(S_netdb_lock_);
+        hent = ::gethostbyname ((char *)_host.c_str());
+#endif // HAVE_THREADS
     if (hent) {
         me._ipaddr.insert (me._ipaddr.begin(),
                            (CORBA::Octet *)hent->h_addr,
                            (CORBA::Octet *)hent->h_addr + hent->h_length);
         return TRUE;
     }
+#ifdef HAVE_THREADS
+    }
+#endif // HAVE_THREADS
 
     if (MICO::Logger::IsLogged (MICO::Logger::Warning)) {
       MICOMT::AutoDebugLock __lock;
@@ -300,8 +321,16 @@ MICO::InetAddress::resolve_host () const
     if (_resolve) {
 	// XXX vector elements need not be continuous ?!
 	assert (_ipaddr.size() < 2 || &_ipaddr[0] + 1 == &_ipaddr[1]);
+#ifdef HAVE_THREADS
+        struct hostent* hent = NULL;
+        {
+            MICOMT::AutoLock lock(S_netdb_lock_);
+            hent = ::gethostbyaddr ((char *)&_ipaddr.front(),
+                                    _ipaddr.size(), AF_INET);
+#else // HAVE_THREADS
 	struct hostent *hent = ::gethostbyaddr ((char *)&_ipaddr.front(),
 						_ipaddr.size(), AF_INET);
+#endif // HAVE_THREADS
 	if (hent) {
 	    string s = hent->h_name;
 	    if ((int)s.find (".") < 0) {
@@ -317,6 +346,9 @@ MICO::InetAddress::resolve_host () const
 		me._host = s;
 	    }
 	}
+#ifdef HAVE_THREADS
+        }
+#endif // HAVE_THREADS
     }
     if (me._host.length() == 0) {
 	// no FQDN found or no database entry. use dotted decimal ...
@@ -431,6 +463,17 @@ MICO::InetAddress::is_local () const
     return FALSE;
 }
 
+CORBA::Boolean
+MICO::InetAddress::is_here () const
+{
+    /*
+     * This test is not necessarily correct, since hostid() could give
+     * a different interface from what ipaddr() gives, fooling the
+     * determination to incorrectly assume an address to be remote.
+     */
+    return hostid() == ipaddr();
+}
+
 CORBA::Address *
 MICO::InetAddress::clone () const
 {
@@ -766,6 +809,12 @@ MICO::UnixAddress::is_local () const
     return FALSE;
 }
 
+CORBA::Boolean
+MICO::UnixAddress::is_here () const
+{
+    return TRUE;
+}
+
 CORBA::Address *
 MICO::UnixAddress::clone () const
 {
