@@ -20,13 +20,32 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "orb_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #include <CORBA-SMALL.h>
 #include <stdio.h>
 #include <string.h>
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iostream>
+#include <iomanip>
+#else
 #include <iostream.h>
 #include <iomanip.h>
+#endif
 #include <mico/template_impl.h>
 
+#endif // FAST_PCH
+
+
+using namespace std;
+
 CORBA::Buffer::Buffer (void *b)
 {
     // readonly buffer with given contents
@@ -131,7 +150,7 @@ CORBA::Buffer::reset (ULong sz)
 }
 
 void
-CORBA::Buffer::resize (ULong needed)
+CORBA::Buffer::doresize (ULong needed)
 {
     assert (!_readonly);
     if (_wptr + needed > _len) {
@@ -145,20 +164,6 @@ CORBA::Buffer::resize (ULong needed)
     }
 }
 
-CORBA::Boolean
-CORBA::Buffer::ralign (ULong modulo)
-{
-    assert (modulo >= 1);
-    assert (_rptr >= _ralignbase);
-    ULong r = (_rptr - _ralignbase) + modulo - 1;
-    r -= r % modulo;
-    r += _ralignbase;
-    if (r > _wptr)
-	return FALSE;
-    _rptr = r;
-    return TRUE;
-}
-
 CORBA::Boolean
 CORBA::Buffer::peek (void *b, ULong blen)
 {
@@ -208,11 +213,9 @@ CORBA::Buffer::get1 (void *p)
 CORBA::Boolean
 CORBA::Buffer::get2 (void *p)
 {
-    assert (_rptr >= _ralignbase);
-    ULong r = ((_rptr - _ralignbase + 1) & ~1L) + _ralignbase;
-    if (r+2 > _wptr)
+    // assert (((_rptr - _ralignbase) % 2) == 0);
+    if (_rptr+2 > _wptr)
 	return FALSE;
-    _rptr = r;
     // assume that pointers can be cast to long
     if (!((_rptr | (long)p)&1)) {
 	*(CORBA::Short *)p = (CORBA::Short &)_buf[_rptr];
@@ -227,11 +230,9 @@ CORBA::Buffer::get2 (void *p)
 CORBA::Boolean
 CORBA::Buffer::get4 (void *p)
 {
-    assert (_rptr >= _ralignbase);
-    ULong r = ((_rptr - _ralignbase + 3) & ~3L) + _ralignbase;
-    if (r+4 > _wptr)
+    // assert (((_rptr - _ralignbase) % 4) == 0);
+    if (_rptr+4 > _wptr)
 	return FALSE;
-    _rptr = r;
     if (!((_rptr | (long)p)&3)) {
 	*(CORBA::Long *)p = (CORBA::Long &)_buf[_rptr];
 	_rptr += 4;
@@ -247,11 +248,9 @@ CORBA::Buffer::get4 (void *p)
 CORBA::Boolean
 CORBA::Buffer::get8 (void *p)
 {
-    assert (_rptr >= _ralignbase);
-    ULong r = ((_rptr - _ralignbase + 7) & ~7L) + _ralignbase;
-    if (r+8 > _wptr)
+    // assert (((_rptr - _ralignbase) % 8) == 0);
+    if (_rptr+8 > _wptr)
 	return FALSE;
-    _rptr = r;
     if (!((_rptr | (long)p)&7)) {
 	*(CORBA::LongLong *)p = (CORBA::LongLong &)_buf[_rptr];
 	_rptr += 8;
@@ -272,11 +271,9 @@ CORBA::Buffer::get8 (void *p)
 CORBA::Boolean
 CORBA::Buffer::get16 (void *p)
 {
-    assert (_rptr >= _ralignbase);
-    ULong r = ((_rptr - _ralignbase + 7) & ~7L) + _ralignbase;
-    if (r+16 > _wptr)
+    // assert (((_rptr - _ralignbase) % 8) == 0);
+    if (_rptr+16 > _wptr)
 	return FALSE;
-    _rptr = r;
     if (!((_rptr | (long)p)&7)) {
 	*((CORBA::LongLong * &)p)++ = (CORBA::LongLong &)_buf[_rptr];
 	_rptr += 8;
@@ -303,20 +300,6 @@ CORBA::Buffer::get16 (void *p)
     return TRUE;
 }
 
-void
-CORBA::Buffer::walign (ULong modulo)
-{
-    assert (!_readonly);
-    assert (modulo >= 1);
-    assert (_wptr >= _walignbase);
-    ULong w = (_wptr - _walignbase) + modulo - 1;
-    w -= w % modulo;
-    w += _walignbase;
-    resize (w - _wptr);
-    while (_wptr < w)
-	_buf[_wptr++] = 0;
-}
-
 void
 CORBA::Buffer::replace (const void *o, ULong blen)
 {
@@ -338,8 +321,7 @@ void
 CORBA::Buffer::put (const void *o, ULong l)
 {
     assert (!_readonly);
-    if (_wptr + l > _len)
-	resize (l);
+    resize (l);
     memcpy (&_buf[_wptr], o, l);
     _wptr += l;
 }
@@ -348,8 +330,7 @@ void
 CORBA::Buffer::put (Octet o)
 {
     assert (!_readonly);
-    if (_wptr + 1 > _len)
-	resize (1);
+    resize (1);
     _buf[_wptr++] = o;
 }
 
@@ -357,20 +338,17 @@ void
 CORBA::Buffer::put1 (const void *p)
 {
     assert (!_readonly);
-    if (_wptr == _len)
-	resize (1);
+    resize (1);
     _buf[_wptr++] = *(const Octet *)p;
 }
 
 void
 CORBA::Buffer::put2 (const void *p)
 {
+    // assert (((_wptr - _walignbase) % 2) == 0);
     assert (!_readonly && _wptr >= _walignbase);
-    if (_wptr+3 > _len)
-	resize (3);
+    resize (2);
     CORBA::Octet *b = _buf + _wptr;
-    if ((_wptr - _walignbase) & 1L)
-	*b++ = 0;
     if (!(((long)b | (long)p)&1)) {
 	*((CORBA::Short *&)b)++ = *(const CORBA::Short *)p;
     } else {
@@ -383,15 +361,10 @@ CORBA::Buffer::put2 (const void *p)
 void
 CORBA::Buffer::put4 (const void *p)
 {
+   // assert (((_wptr - _walignbase) % 4) == 0);
     assert (!_readonly && _wptr >= _walignbase);
-    if (_wptr+7 > _len)
-	resize (7);
+    resize (4);
     CORBA::Octet *b = _buf + _wptr;
-    switch ((_wptr - _walignbase) & 3L) {
-    case 1: *b++ = 0;
-    case 2: *b++ = 0;
-    case 3: *b++ = 0;
-    }
     if (!(((long)b | (long)p)&3)) {
 	*((CORBA::Long * &)b)++ = *(const CORBA::Long *)p;
     } else {
@@ -406,19 +379,10 @@ CORBA::Buffer::put4 (const void *p)
 void
 CORBA::Buffer::put8 (const void *p)
 {
+    // assert (((_wptr - _walignbase) % 8) == 0);
     assert (!_readonly && _wptr >= _walignbase);
-    if (_wptr+15 > _len)
-	resize (15);
+    resize (8);
     CORBA::Octet *b = _buf + _wptr;
-    switch ((_wptr - _walignbase) & 7L) {
-    case 1: *b++ = 0;
-    case 2: *b++ = 0;
-    case 3: *b++ = 0;
-    case 4: *b++ = 0;
-    case 5: *b++ = 0;
-    case 6: *b++ = 0;
-    case 7: *b++ = 0;
-    }
     if (!(((long)b | (long)p)&7)) {
 	*((CORBA::LongLong *&)b)++ = *(const CORBA::LongLong *)p;
     } else {
@@ -438,19 +402,10 @@ CORBA::Buffer::put8 (const void *p)
 void
 CORBA::Buffer::put16 (const void *p)
 {
+    //  assert (((_wptr - _walignbase) % 8) == 0);
     assert (!_readonly && _wptr >= _walignbase);
-    if (_wptr+23 > _len)
-	resize (23);
+    resize (16);
     CORBA::Octet *b = _buf + _wptr;
-    switch ((_wptr - _walignbase) & 7L) {
-    case 1: *b++ = 0;
-    case 2: *b++ = 0;
-    case 3: *b++ = 0;
-    case 4: *b++ = 0;
-    case 5: *b++ = 0;
-    case 6: *b++ = 0;
-    case 7: *b++ = 0;
-    }
     if (!(((long)b | (long)p)&7)) {
 	*((CORBA::LongLong *&)b)++ = *((const CORBA::LongLong * &)p)++;
 	*((CORBA::LongLong *&)b)++ = *(const CORBA::LongLong *)p;
