@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2003 by The Mico Team
+ *  Copyright (c) 1997-2007 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -41,7 +41,6 @@
 #include <ctype.h>
 #include <mico/throw.h>
 #include <mico/impl.h>
-#include <mico/intercept.h>
 #include <mico/util.h>
 #include <mico/template_impl.h>
 #include <mico/os-misc.h>
@@ -537,8 +536,6 @@ CORBA::Request::Request (Object_ptr o, Context_ptr c,
     orb->create_context_list (_clist);
     orb->create_exception_list (_elist);
     _orbreq = new MICO::LocalRequest (this);
-    _iceptreq = Interceptor::ClientInterceptor::_create_request
-	(_object, _opname, *_orbreq->context(), this);
     _cb = 0;
     _cri = PInterceptor::PI::_create_cri
 	(_object, _opname, 0, _args, _elist, _clist, _context, _res, TRUE);
@@ -587,8 +584,6 @@ CORBA::Request::Request (Object_ptr o,
     if (CORBA::is_nil (_elist))
 	orb->create_exception_list (_elist);
     _orbreq = new MICO::LocalRequest (this);
-    _iceptreq = Interceptor::ClientInterceptor::_create_request
-	(_object, _opname, *_orbreq->context(), this);
     _cb = 0;
     _cri = PInterceptor::PI::_create_cri
 	(_object, _opname, 0, _args, _elist, _clist, _context, _res, TRUE);
@@ -623,8 +618,6 @@ CORBA::Request::Request (Object_ptr o, const char *op)
     _orbid = 0;
     _flags = 0;
     _orbreq = new MICO::LocalRequest (this);
-    _iceptreq = Interceptor::ClientInterceptor::_create_request
-	(_object, _opname, *_orbreq->context(), this);
     _cb = 0;
     _cri = PInterceptor::PI::_create_cri
 	(_object, _opname, 0, _args, _elist, _clist, _context, _res, TRUE);
@@ -642,7 +635,6 @@ CORBA::Request::~Request ()
     CORBA::release (_clist);
     CORBA::release (_elist);
     CORBA::release (_orbreq);
-    CORBA::release (_iceptreq);
     CORBA::release (_cri);
 }
 
@@ -792,15 +784,15 @@ CORBA::Request::send_oneway ()
 {
     MICO_OBJ_CHECK (this);
 
-    if (!Interceptor::ClientInterceptor::
-	_exec_initialize_request ((Interceptor::LWRequest_ptr)_iceptreq,
-				  _environm)) {
-	return;
-    }
     ORB_ptr orb = _object->_orbnc();
-    PInterceptor::PI::_send_request_ip
-	(_cri, CORBA::ORB::get_msgid(_orbid), _args, this->contexts(), this->ctx(),
-	 _orbreq->context(), FALSE);
+    try {
+	PInterceptor::PI::_send_request_ip
+	    (_cri, CORBA::ORB::get_msgid(_orbid), _args, this->contexts(), this->ctx(),
+	     _orbreq->context(), FALSE);
+    } catch (...) {
+	this->env()->exception(_cri->exception()->_clone());
+	throw;
+    }
 
     CORBA::ORBMsgId __id = orb->invoke_async
 	(_object, _orbreq, Principal::_nil(), FALSE);
@@ -811,15 +803,23 @@ CORBA::Request::send_oneway ()
     if (__id != NULL) {
 	cerr << "dii.cc hack pi...." << endl;
 	CORBA::OBJECT_NOT_EXIST ex;
-	PInterceptor::PI::_receive_exception_ip
-	    (_cri, PortableInterceptor::SYSTEM_EXCEPTION, ex._clone(),
-	     _orbreq->context());
+	try {
+	    PInterceptor::PI::_receive_exception_ip
+		(_cri, PortableInterceptor::SYSTEM_EXCEPTION, ex,
+		 _orbreq->context());
+	} catch (...) {
+	    this->env()->exception(_cri->exception()->_clone());
+	    throw;
+	}
     }
     else {
-	PInterceptor::PI::_receive_other_ip(_cri);
+	try {
+	    PInterceptor::PI::_receive_other_ip(_cri);
+	} catch (...) {
+	    this->env()->exception(_cri->exception()->_clone());
+	    throw;
+	}
     }
-    Interceptor::ClientInterceptor::
-	_exec_after_marshal ((Interceptor::LWRequest_ptr)_iceptreq, _environm);
 }
 
 void
@@ -829,40 +829,25 @@ CORBA::Request::send_deferred (RequestCallback *cb)
 
     _cb = cb;
 
-    if (!Interceptor::ClientInterceptor::
-	_exec_initialize_request ((Interceptor::LWRequest_ptr)_iceptreq,
-				  _environm)) {
-	if (_cb)
-	    _cb->callback (this, RequestCallback::RequestDone);
-	_cb = 0;
-	return;
-    }
-
-    _invoke_pending = TRUE;
-
     ORB_ptr orb = _object->_orbnc();
     _orbid = orb->new_orbid();
 //      orb->invoke_async (_object, _orbreq, Principal::_nil(),
 //                         TRUE, _cb ? this : 0, _orbid);
 
 //      _msgid = orb->new_msgid();
-    PInterceptor::PI::_send_request_ip
-	(_cri, CORBA::ORB::get_msgid(_orbid), _args, this->contexts(),
-	 this->ctx(), _orbreq->context());
+    try {
+	PInterceptor::PI::_send_request_ip
+	    (_cri, CORBA::ORB::get_msgid(_orbid), _args, this->contexts(),
+	     this->ctx(), _orbreq->context());
+    } catch (...) {
+	this->env()->exception(_cri->exception()->_clone());
+	throw;
+    }
     
+    _invoke_pending = TRUE;
+
     orb->invoke_async(_object, _orbreq, Principal::_nil(),
 		      TRUE, _cb ? this : 0, _orbid);
-	
-    if (_invoke_pending && !Interceptor::ClientInterceptor::
-	_exec_after_marshal ((Interceptor::LWRequest_ptr)_iceptreq,
-			     _environm)) {
-	orb->cancel (_orbid);
-	_invoke_pending = FALSE;
-	if (_cb)
-	    _cb->callback (this, RequestCallback::RequestDone);
-	_cb = 0;
-	return;
-    }
 }
 
 void
@@ -889,14 +874,6 @@ CORBA::Request::get_response (Boolean block)
 	}
 
 	// XXX called multiple times in case of Forward
-	if (!Interceptor::ClientInterceptor::
-	    _exec_before_unmarshal ((Interceptor::LWRequest_ptr)_iceptreq,
-				    _environm)) {
-	    orb->cancel (_orbid);
-	    _invoke_pending = FALSE;
-	    _cb = 0;
-	    return;
-	}
 
 	GIOP::AddressingDisposition ad;
 	rs = orb->get_invoke_reply (_orbid, nobj, dummy, ad);
@@ -907,17 +884,28 @@ CORBA::Request::get_response (Boolean block)
 	    // XXX what if 'object' is not a stub ???
 	    assert (_object.in() && nobj.in());
 	    _object->_forward (nobj);
-	    PInterceptor::PI::_receive_other_ip
-		(_cri, PortableInterceptor::LOCATION_FORWARD, _object,
-		 dummy->context());
+	    try {
+		PInterceptor::PI::_receive_other_ip
+		    (_cri, PortableInterceptor::LOCATION_FORWARD, _object,
+		     dummy->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		throw;
+	    }
 	    CORBA::release(_cri);
 	    //_msgid = orb->new_msgid();
 	    _orbid = orb->new_orbid();
 	    _cri = PInterceptor::PI::_create_cri
 		(_object, _opname, _elist, _res);
-	    PInterceptor::PI::_send_request_ip
-		(_cri, CORBA::ORB::get_msgid(_orbid), _args, _clist, _context,
-		 _orbreq->context());
+	    try {
+		PInterceptor::PI::_send_request_ip
+		    (_cri, CORBA::ORB::get_msgid(_orbid), _args, this->contexts(), this->ctx(),
+		     _orbreq->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		_invoke_pending = FALSE;
+		throw;
+	    }
 	    //_msgid = orb->invoke_async (_object, _orbreq, Principal::_nil(),
 	    //TRUE, 0, _msgid);
 	    _orbid = orb->invoke_async (_object, _orbreq, Principal::_nil(),
@@ -925,15 +913,27 @@ CORBA::Request::get_response (Boolean block)
 	    break;
 
 	case InvokeOk:
-	    PInterceptor::PI::_receive_reply_ip
-		(_cri, *_res->value(), _args, dummy->context(), TRUE);
+	    try {
+		PInterceptor::PI::_receive_reply_ip
+		    (_cri, *_res->value(), _args, dummy->context(), TRUE);
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		_invoke_pending = FALSE;
+		throw;
+	    }
 	    _invoke_pending = FALSE;
 	    break;
 
 	case CORBA::InvokeSysEx:
-	    PInterceptor::PI::_receive_exception_ip
-		(_cri, PortableInterceptor::SYSTEM_EXCEPTION,
-		 _environm->exception()->_clone(), dummy->context());
+	    try {
+		PInterceptor::PI::_receive_exception_ip
+		    (_cri, PortableInterceptor::SYSTEM_EXCEPTION,
+		     _environm->exception(), dummy->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		_invoke_pending = FALSE;
+		throw;
+	    }
 	    if (_object->_is_forwarded()) {
 		/*
 		 * [15-44] says:
@@ -963,9 +963,15 @@ CORBA::Request::get_response (Boolean block)
 		    _orbid = orb->new_orbid();
 		    _cri = PInterceptor::PI::_create_cri
 			(_object, _opname, _elist, _res);
-		    PInterceptor::PI::_send_request_ip
-			(_cri, CORBA::ORB::get_msgid(_orbid), _args, _clist,
-			 _context, _orbreq->context());
+		    try {
+			PInterceptor::PI::_send_request_ip
+			    (_cri, CORBA::ORB::get_msgid(_orbid), _args, _clist,
+			     _context, _orbreq->context());
+		    } catch (...) {
+			this->env()->exception(_cri->exception()->_clone());
+			_invoke_pending = FALSE;
+			throw;
+		    }
 		    //_msgid = orb->invoke_async
 		    //(_object, _orbreq, Principal::_nil(), TRUE, 0, _msgid);
 		    _orbid = orb->invoke_async
@@ -978,16 +984,27 @@ CORBA::Request::get_response (Boolean block)
 
 	case InvokeUsrEx:
 	    decode_user_exception ();
-	    PInterceptor::PI::_receive_exception_ip
-		(_cri, PortableInterceptor::USER_EXCEPTION,
-		 _environm->exception()->_clone(), dummy->context());
+	    try {
+		PInterceptor::PI::_receive_exception_ip
+		    (_cri, PortableInterceptor::USER_EXCEPTION,
+		     _environm->exception(), dummy->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		_invoke_pending = FALSE;
+		throw;
+	    }
 	    _invoke_pending = FALSE;
 	    break;
 
 	case InvokeAddrDisp:
 	    _object->_ior_fwd()->addressing_disposition (ad);
-	    PInterceptor::PI::_receive_other_ip
-		(_cri, PortableInterceptor::TRANSPORT_RETRY, dummy->context());
+	    try {
+		PInterceptor::PI::_receive_other_ip
+		    (_cri, PortableInterceptor::TRANSPORT_RETRY, dummy->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		throw;
+	    }
 	    CORBA::release (_cri);
 	    //_msgid = orb->new_msgid();
 	    if (_orbid != NULL)
@@ -995,9 +1012,14 @@ CORBA::Request::get_response (Boolean block)
 	    _orbid = orb->new_orbid();
 	    _cri = PInterceptor::PI::_create_cri
 		(_object, _opname, _elist, _res);
-	    PInterceptor::PI::_send_request_ip
-		(_cri, CORBA::ORB::get_msgid(_orbid), _args, _clist,
-		 _context, _orbreq->context());
+	    try {
+		PInterceptor::PI::_send_request_ip
+		    (_cri, CORBA::ORB::get_msgid(_orbid), _args, _clist,
+		     _context, _orbreq->context());
+	    } catch (...) {
+		this->env()->exception(_cri->exception()->_clone());
+		throw;
+	    }
 	    //_msgid = orb->invoke_async (_object, _orbreq, Principal::_nil(),
 	    //TRUE, 0, _msgid);
 	    _orbid = orb->invoke_async(_object, _orbreq, Principal::_nil(),
@@ -1009,13 +1031,6 @@ CORBA::Request::get_response (Boolean block)
 	}
     }
 
-    if (!Interceptor::ClientInterceptor::
-	_exec_finish_request ((Interceptor::LWRequest_ptr)_iceptreq,
-			      _environm)) {
-	_cb = 0;
-	return;
-    }
-
     _cb = 0;
 
     if (!_invoke_pending && rs == CORBA::InvokeSysEx)
