@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2005 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -1424,8 +1424,11 @@ DynUnion_impl::update_element (CORBA::Long idx)
     if (nidx == _member_idx)
 	return;
 
-    if (_elements.size() == 2)
+    if (_elements.size() == 2) {
+        // kcg: we need to destroy poped dynany first!
+        _elements[_elements.size() - 1]->destroy();
 	_elements.pop_back ();
+    }
     if (nidx >= 0) {
 	CORBA::TypeCode_var tc = _type->unalias()->member_type (nidx);
 	_elements.push_back (_factory()->create_dyn_any_from_type_code (tc));
@@ -2465,6 +2468,7 @@ DynValue_impl::set_members_as_dyn_any (
 	if (strlen (value[i].id) > 0 &&
             strcmp (tc->member_name_inherited(i), value[i].id))
 	    mico_throw (TypeMismatch ());
+        this->update_element(i);
 	_elements[i]->assign (value[i].value.in());
     }
     _index = _elements.size() > 0 ? 0 : -1;
