@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2005 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -82,6 +82,19 @@ power10 (int x)
     return s;
 }
 
+#ifdef CRAY
+static MICO_LongDouble
+ceill (MICO_LongDouble value)
+{
+    MICO_LongLong f = (MICO_LongLong)value;
+    if ( (MICO_LongDouble)f == value ) {
+	return (MICO_LongDouble)f;
+    } else {
+	return (MICO_LongDouble) (f + 1);
+    }
+}
+#endif // CRAY
+
 static MICO_LongDouble
 epsilonl (MICO_LongDouble v)
 {
