@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2006 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -249,7 +249,12 @@ CORBA::IOR::copy (const IOR &ior)
 	add_profile (ior.tags[i]->clone());
     oid = ior.oid;
     _active_profile_index = ior._active_profile_index;
-    _active_profile = get_profile (_active_profile_index);
+    if (ior._active_profile != NULL) {
+        _active_profile = get_profile (_active_profile_index);
+    }
+    else {
+        _active_profile = NULL;
+    }
     _addressing_disposition = ior._addressing_disposition;
 }
 
@@ -377,7 +382,7 @@ CORBA::IOR::add_profile (IORProfile *prof)
     int i = tags.size();
     while (--i >= 0 && *prof < *tags[i])
 	;
-    tags.insert (tags.begin()+i+1, prof);
+    tags.insert (tags.begin()+(i+1), prof);
 }
 
 void
@@ -837,6 +842,10 @@ MICO::IIOPProfile::IIOPProfile (CORBA::Octet *o, CORBA::ULong l,
     memcpy (objkey, o, length);
     
     myaddr = ia;
+
+    object_reg = new RegAddr;
+    object_reg->reged = TRUE;
+    object_reg->refcnt = 1;
 }
 
 MICO::IIOPProfile::IIOPProfile (const IIOPProfile &ip)
@@ -848,11 +857,16 @@ MICO::IIOPProfile::IIOPProfile (const IIOPProfile &ip)
     comps = ip.comps;
     objkey = new CORBA::Octet[length = ip.length];
     memcpy (objkey, ip.objkey, length);
+    object_reg = ip.object_reg;
+    object_reg->refcnt++;
 }
 
 MICO::IIOPProfile::~IIOPProfile ()
 {
     delete[] objkey;
+    if (--object_reg->refcnt == 0) {
+	delete object_reg;
+    }
 }
 
 MICO::IIOPProfile &
@@ -864,6 +878,11 @@ MICO::IIOPProfile::operator= (const IIOPProfile &ip)
 	myaddr = ip.myaddr;
 	comps = ip.comps;
 	objectkey (ip.objkey, ip.length);
+	if (--object_reg->refcnt == 0) {
+	    delete object_reg;
+	}
+	object_reg = ip.object_reg;
+	object_reg->refcnt++;
     }
     return *this;
 }
@@ -901,6 +920,12 @@ MICO::IIOPProfile::addr () const
     return &myaddr;
 }
 
+void
+MICO::IIOPProfile::addr (const MICO::InetAddress &ia)
+{
+    myaddr = ia;
+}
+
 MICO::IIOPProfile::ProfileId
 MICO::IIOPProfile::id () const
 {
@@ -919,6 +944,43 @@ MICO::IIOPProfile::objectkey (CORBA::Octet *o, CORBA::Long l)
     delete[] objkey;
     objkey = new CORBA::Octet[length = l];
     memcpy (objkey, o, length);
+    if (!object_reg->reged) {
+	CORBA::ORB_var orb = CORBA::ORB_instance("mico-local-orb");
+	CORBA::Object_var obj =
+	    orb->resolve_initial_references("MobileTerminalBridge");
+	/*
+	 * XXX - Maybe this needs a custom marshalling routine so we can
+	 *       avoid DII
+	 */
+	CORBA::Request_var req = obj->_request("register_profile");
+	req->add_in_arg() <<=
+	    (CORBA::ULong) CORBA::IORProfile::TAG_INTERNET_IOP;
+	MICO::CDREncoder ec;
+	encode(ec);
+	CORBA::OctetSeq prof(ec.buffer()->length(), ec.buffer()->length(),
+			     ec.buffer()->data(), FALSE);
+	req->add_in_arg() <<= prof;
+	req->set_return_type(CORBA::_tc_string);
+	req->invoke();
+	CORBA::Exception *ex = req->env()->exception();
+	if (ex == NULL) {
+	    const char *addr;
+	    req->return_value() >>= addr;
+	    CORBA::Address *gaddr = CORBA::Address::parse(addr);
+	    assert(gaddr != NULL);
+	    MICO::InetAddress *iaddr =
+		dynamic_cast<MICO::InetAddress *>(gaddr);
+	    assert(iaddr != NULL);
+	    myaddr = *iaddr;
+	} else if (CORBA::UserException::_downcast(ex)) {
+	    // The only user exception is AddressNotAvailable
+	    // XXX - I don't have a clue what to do now
+	} else {
+	    // A system exception
+	    // XXX - Maybe we should throw something here?
+	}
+	object_reg->reged = TRUE;
+    }
 }
 
 const CORBA::Octet *
@@ -956,6 +1018,12 @@ MICO::IIOPProfile::print (ostream &o) const
   comps.print (o);
 }
 
+void
+MICO::IIOPProfile::prepare_mobile ()
+{
+    object_reg->reged = FALSE;
+}
+
 CORBA::IORProfile *
 MICO::IIOPProfile::clone () const
 {
@@ -1625,7 +1693,7 @@ CORBA::MultiComponent::add_component (Component *c)
     int i = _comps.size();
     while (--i >= 0 && *c < *_comps[i])
 	;
-    _comps.insert (_comps.begin()+i+1, c);
+    _comps.insert (_comps.begin()+(i+1), c);
 }
 
 void
