@@ -133,7 +133,6 @@ HANDLE OSMisc::SignalMutex=NULL;
 /**************************** UnixProcess *****************************/
 
 
-#ifdef HAVE_NAMESPACE
 namespace MICO {
 
   MICO::UnixProcess::ListProcess UnixProcess::_procs;
@@ -147,9 +146,6 @@ namespace MICO {
   int MICO::UnixProcess::s_stop_waiting=FALSE;
   
 };
-#else
-MICO::UnixProcess::ListProcess MICO::UnixProcess::_procs;
-#endif
 
 MICO::UnixProcess::UnixProcess (const char *cmd, MICO::ProcessCallback *cb)
 {
@@ -190,7 +186,7 @@ CORBA::Boolean
 MICO::UnixProcess::run ()
 {
 #ifdef _POCKET_PC
-	NOT_IMPLEMENTED;
+	MICO_NOT_IMPLEMENTED;
 	return 1;
 #else
     STARTUPINFO StartupInfo;    
@@ -259,7 +255,7 @@ MICO::UnixProcess::process_died(DWORD pid)
             
             if ((*i)->_cb)
             {
-                CORBA::ORB_ptr orb = CORBA::ORB_instance("mico-local-orb");
+                CORBA::ORB_var orb = CORBA::ORB_instance("mico-local-orb");
                 CORBA::Dispatcher *disp = orb->dispatcher();
                 disp->remove (*i, CORBA::Dispatcher::Timer);
 		 disp->tm_event (*i, 0);
@@ -274,7 +270,7 @@ MICO::UnixProcess::process_died(DWORD pid)
 void 
 MICO::UnixProcess::_init() {
 #ifdef _POCKET_PC
-	NOT_IMPLEMENTED;
+	MICO_NOT_IMPLEMENTED;
 #else
   HANDLE hProcessExitEvent = NULL;
   char  szExitEventName[] = "Process00000000";
@@ -303,7 +299,7 @@ MICO::UnixProcess::_init() {
 void
 MICO::UnixProcess::win32_process_init() {
 #ifdef _POCKET_PC
-	NOT_IMPLEMENTED;
+	MICO_NOT_IMPLEMENTED;
 #else
   unsigned int	threadid = 0;
 
@@ -330,7 +326,7 @@ void
 #endif
 __stdcall MICO::UnixProcess::ThreadExitFunc(VOID *arg) {
 #ifdef _POCKET_PC
-	NOT_IMPLEMENTED;
+	MICO_NOT_IMPLEMENTED;
 #else
   HANDLE hProcessExitEvent = NULL;
   char szExitEventName[] = "Process00000000";
@@ -340,7 +336,7 @@ __stdcall MICO::UnixProcess::ThreadExitFunc(VOID *arg) {
   if (hProcessExitEvent != NULL) {
     WaitForSingleObject(hProcessExitEvent, INFINITE);
     ResetEvent(hProcessExitEvent);
-  CORBA::ORB_ptr orb = CORBA::ORB_instance("mico-local-orb");
+  CORBA::ORB_var orb = CORBA::ORB_instance("mico-local-orb");
   orb->shutdown(FALSE);
   orb->perform_work();
   }
@@ -443,28 +439,47 @@ MICO::UnixProcess::callback (CORBA::Dispatcher *disp,
 MICO::UnixSharedLib::UnixSharedLib (const char *name)
 {
     _name = name;
-    _handle = 0;
+    _handle = ::LoadLibrary(name);
 }
 
 MICO::UnixSharedLib::~UnixSharedLib ()
 {
+    if (_handle != NULL)
+    {
+	::FreeLibrary((HINSTANCE)_handle);
+    }
 }
 
 void *
 MICO::UnixSharedLib::symbol (const char *sym)
 {
-    return 0;
+    return ::GetProcAddress((HINSTANCE)_handle,sym);
 }
 
 const char *
 MICO::UnixSharedLib::error ()
 {
-    return "no shlib support";
+  LPVOID lpMsgBuf = NULL; //Here is the Pointer to Error String.
+  ::FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | 
+		  FORMAT_MESSAGE_FROM_SYSTEM | 
+		  FORMAT_MESSAGE_IGNORE_INSERTS,
+		  NULL,
+		  ::GetLastError(),
+		  MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
+		  (LPTSTR) &lpMsgBuf,
+		  0,
+		  NULL    
+		  );
+  const char *err = (const char*)lpMsgBuf;
+  if (err)
+    _error = err;
+  ::LocalFree(lpMsgBuf);
+  return _error.c_str();
 }
 
 MICO::UnixSharedLib::operator CORBA::Boolean ()
 {
-    return FALSE;
+    return !!_handle;
 }
 
 const char *
@@ -473,13 +488,3 @@ MICO::UnixSharedLib::name ()
     return _name.c_str();
 }
 
-
-
-
-
-
-
-
-
-
-
