@@ -1,6 +1,6 @@
 //
 //  MICO PI --- an Open Source Portable Interceptor implementation
-//  Copyright (C) 2001, 2002, 2003 ObjectSecurity Ltd.
+//  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2008 ObjectSecurity Ltd.
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Library General Public
@@ -47,18 +47,21 @@ using namespace std;
 //
 
 PInterceptor::Current_impl* PInterceptor::Current_impl::S_current_ = NULL;
-list<PortableInterceptor::ORBInitializer_ptr>
-PInterceptor::PI::S_initializers_;
 PortableInterceptor::SlotId PInterceptor::PI::S_max_slot_id_ = 0;
 PInterceptor::PI::PolicyFactoryMap PInterceptor::PI::S_pfmap_;
 MICOMT::Mutex PInterceptor::PI::S_client_lock_(FALSE, MICOMT::Mutex::Recursive);
 MICOMT::Mutex PInterceptor::PI::S_server_lock_(FALSE, MICOMT::Mutex::Recursive);
 PInterceptor::PI::IORList PInterceptor::PI::S_ior_interceptors_;
+PInterceptor::PI::IORList PInterceptor::PI::S_ior_interceptors_prepared_;
 
 vector<PortableInterceptor::ClientRequestInterceptor_ptr>
 PInterceptor::PI::S_client_req_int_;
+vector<PortableInterceptor::ClientRequestInterceptor_ptr>
+PInterceptor::PI::S_client_req_int_prepared_;
 vector<PortableInterceptor::ServerRequestInterceptor_ptr>
 PInterceptor::PI::S_server_req_int_;
+vector<PortableInterceptor::ServerRequestInterceptor_ptr>
+PInterceptor::PI::S_server_req_int_prepared_;
 
 stack<PInterceptor::PI::ClientFlowStack*> PInterceptor::PI::S_client_stack_;
 stack<PInterceptor::PI::ServerFlowStack*> PInterceptor::PI::S_server_stack_;
@@ -67,7 +70,7 @@ void
 PortableInterceptor::register_orb_initializer
 (PortableInterceptor::ORBInitializer_ptr init)
 {
-    PInterceptor::PI::S_initializers_.push_back
+    PInterceptor::PI::initializers().push_back
 	(PortableInterceptor::ORBInitializer::_duplicate(init));
 }
 
@@ -80,18 +83,64 @@ PortableInterceptor::destroy_all_interceptors()
 	 it_ior++) {
 	(*it_ior)->destroy();
     }
+    PInterceptor::PI::S_ior_interceptors_.erase
+	(PInterceptor::PI::S_ior_interceptors_.begin(),
+	 PInterceptor::PI::S_ior_interceptors_.end());
     vector<ClientRequestInterceptor_ptr>::iterator it_client;
     for (it_client = PInterceptor::PI::S_client_req_int_.begin();
 	 it_client != PInterceptor::PI::S_client_req_int_.end();
 	 it_client++) {
 	(*it_client)->destroy();
+	CORBA::release(*it_client);
     }
+    PInterceptor::PI::S_client_req_int_.erase
+	(PInterceptor::PI::S_client_req_int_.begin(),
+	 PInterceptor::PI::S_client_req_int_.end());
     vector<ServerRequestInterceptor_ptr>::iterator it_server;
     for (it_server = PInterceptor::PI::S_server_req_int_.begin();
 	 it_server != PInterceptor::PI::S_server_req_int_.end();
 	 it_server++) {
 	(*it_server)->destroy();
+	CORBA::release(*it_server);
     }
+    PInterceptor::PI::S_server_req_int_.erase
+	(PInterceptor::PI::S_server_req_int_.begin(),
+	 PInterceptor::PI::S_server_req_int_.end());
+}
+
+
+void
+PortableInterceptor::backup_initializers()
+{
+    PInterceptor::PI::initializers_backup() = PInterceptor::PI::initializers();
+}
+
+
+void
+PortableInterceptor::restore_initializers()
+{
+    PInterceptor::PI::initializers() = PInterceptor::PI::initializers_backup();
+}
+
+
+void
+PortableInterceptor::commit_initialized_interceptors()
+{
+    PInterceptor::PI::S_client_req_int_
+        = PInterceptor::PI::S_client_req_int_prepared_;
+    PInterceptor::PI::S_client_req_int_prepared_.erase
+        (PInterceptor::PI::S_client_req_int_prepared_.begin(),
+         PInterceptor::PI::S_client_req_int_prepared_.end());
+    PInterceptor::PI::S_server_req_int_
+        = PInterceptor::PI::S_server_req_int_prepared_;
+    PInterceptor::PI::S_server_req_int_prepared_.erase
+        (PInterceptor::PI::S_server_req_int_prepared_.begin(),
+         PInterceptor::PI::S_server_req_int_prepared_.end());
+    PInterceptor::PI::S_ior_interceptors_
+        = PInterceptor::PI::S_ior_interceptors_prepared_;
+    PInterceptor::PI::S_ior_interceptors_prepared_.erase
+        (PInterceptor::PI::S_ior_interceptors_prepared_.begin(),
+         PInterceptor::PI::S_ior_interceptors_prepared_.end());
 }
 
 #ifdef HAVE_THREADS
@@ -366,8 +415,8 @@ PInterceptor::RequestInfo_impl::~RequestInfo_impl()
 	CORBA::release(object_);
     if (!CORBA::is_nil(fwd_object_))
 	CORBA::release(fwd_object_);
-    if (!CORBA::is_nil(ctx_list_orig_))
-	CORBA::release(ctx_list_orig_);
+    if (this->exception_ != NULL)
+        delete exception_;
 }
 
 CORBA::ULong
@@ -1375,14 +1424,6 @@ PInterceptor::ServerRequestInfo_impl::target_most_derived_interface()
     const char* oaid = object_adapter_->get_oaid();
     if (oaid == NULL)
 	return CORBA::string_dup("");
-    if (strcmp(oaid, "mico-local-boa") == 0) { // BOA
-	MICO::BOAImpl* boa = dynamic_cast<MICO::BOAImpl*>(object_adapter_);
-	assert(boa != NULL);
-	CORBA::Object_ptr skel = boa->skeleton(object_);
-	if (skel == NULL)
-	    return CORBA::string_dup("");
-	return CORBA::string_dup(skel->_repoid());
-    }
     char* ret = CORBA::string_dup("");
     MICOPOA::POA_impl* poa = dynamic_cast<MICOPOA::POA_impl*>
 	(object_adapter_);
@@ -1397,7 +1438,18 @@ PInterceptor::ServerRequestInfo_impl::target_most_derived_interface()
 	try {
 	    serv = poa->get_servant();
 	} catch (...) {
-	    sc = FALSE;
+            // handle servant locator case
+            CORBA::ORB_var orb = CORBA::ORB_instance("mico-local-orb", FALSE);
+            assert(!CORBA::is_nil(orb));
+            CORBA::Object_var obj = orb->resolve_initial_references("POACurrent");
+            PortableServer::Current_var current = PortableServer::Current::_narrow(obj);
+            assert(!CORBA::is_nil(current));
+            try {
+                serv = current->get_servant();
+            }
+            catch (...) {
+                sc = FALSE;
+            }
 	}
     }
     if (!sc) {
@@ -1618,10 +1670,10 @@ PInterceptor::ORBInitInfo_impl::ORBInitInfo_impl
  char** argv)
 {
     orb_ = CORBA::ORB::_duplicate(orb);
-    orb_id_ = CORBA::string_dup(id);
+    orb_id_ = id;
     CORBA::ULong length = 0;
     args_.length(length);
-    for (int i=1; i<argc; i++) {
+    for (int i=0; i<argc; i++) {
 	args_.length(length+1);
 	args_[length] = (const char *)argv[i];
 	length++;
@@ -1629,7 +1681,8 @@ PInterceptor::ORBInitInfo_impl::ORBInitInfo_impl
     // _args requires further processing via MICOGetOpt!	
 }
 
-PInterceptor::ORBInitInfo_impl::~ORBInitInfo_impl() {
+PInterceptor::ORBInitInfo_impl::~ORBInitInfo_impl()
+{
 }
 
 CORBA::StringSeq*
@@ -1852,6 +1905,23 @@ PInterceptor::PI::_init()
 {
 }
 
+
+vector<PortableInterceptor::ORBInitializer_var>&
+PInterceptor::PI::initializers()
+{
+    static vector<PortableInterceptor::ORBInitializer_var> inits;
+    return inits;
+}
+
+
+vector<PortableInterceptor::ORBInitializer_var>&
+PInterceptor::PI::initializers_backup()
+{
+    static vector<PortableInterceptor::ORBInitializer_var> back_inits;
+    return back_inits;
+}
+
+
 void
 PInterceptor::PI::_exec_client
 (PortableInterceptor::ClientRequestInfo_ptr ri,
@@ -2183,7 +2253,7 @@ PInterceptor::PI::_receive_exception_ip
 	// any client interceptor registered?
 	cri->reply_status(PortableInterceptor::USER_EXCEPTION);
 	cri->icept_oper(PInterceptor::RECEIVE_EXCEPTION);
-	cri->exception(exception);
+	cri->exception(exception->_clone());
 	cri->set_reply_service_context_list(reply_scl);
 	PInterceptor::PI::_exec_receive_exception(cri); // end point
     }
@@ -2202,7 +2272,7 @@ PInterceptor::PI::_receive_exception_ip
 	// any client interceptor registered?
 	cri->reply_status(PortableInterceptor::USER_EXCEPTION);
 	cri->icept_oper(PInterceptor::RECEIVE_EXCEPTION);
-	cri->exception(exception);
+	cri->exception(exception->_clone());
 	cri->contexts(contexts);
 	cri->operation_context(operation_context);
 	cri->set_reply_service_context_list(reply_scl);
@@ -2679,8 +2749,8 @@ void
 PInterceptor::PI::_exec_add_client_interceptor
 (PortableInterceptor::ClientRequestInterceptor_ptr interceptor)
 {
-    string i_name = interceptor->name();
-    if (i_name != "") {
+    CORBA::String_var i_name = interceptor->name();
+    if (strcmp(i_name.in(), "") != 0) {
 	// it's non-anonymous interceptor
 	// so we have to check if it has unique name
 	// as CORBA 2.6 (21.7.2.1) says
@@ -2688,12 +2758,15 @@ PInterceptor::PI::_exec_add_client_interceptor
 	for (it = S_client_req_int_.begin();
 	     it != S_client_req_int_.end();
 	     it++) {
-	    string s = (*it)->name();
-	    if (i_name == s)
-		mico_throw(PortableInterceptor::ORBInitInfo::DuplicateName());
+	    CORBA::String_var s = (*it)->name();
+	    if (strcmp(i_name.in(), s.in()) == 0) {
+		PortableInterceptor::ORBInitInfo::DuplicateName ex;
+		ex.name = s.in();
+		mico_throw(ex);
+	    }
 	}
     }
-    S_client_req_int_.push_back
+    S_client_req_int_prepared_.push_back
 	(ClientRequestInterceptor::_duplicate(interceptor));
 }
 
@@ -2701,8 +2774,8 @@ void
 PInterceptor::PI::_exec_add_server_interceptor
 (PortableInterceptor::ServerRequestInterceptor_ptr interceptor)
 {
-    string i_name = interceptor->name();
-    if (i_name != "") {
+    CORBA::String_var i_name = interceptor->name();
+    if (strcmp(i_name, "") != 0) {
 	// it's non-anonymous interceptor
 	// so we have to check if it has unique name
 	// as CORBA 2.6 (21.7.2.1) says
@@ -2710,12 +2783,15 @@ PInterceptor::PI::_exec_add_server_interceptor
 	for (it = S_server_req_int_.begin();
 	     it != S_server_req_int_.end();
 	     it++) {
-	    string s = (*it)->name();
-	    if (i_name == s)
-		mico_throw(PortableInterceptor::ORBInitInfo::DuplicateName());
+	    CORBA::String_var s = (*it)->name();
+	    if (strcmp(i_name.in(), s.in()) == 0) {
+		PortableInterceptor::ORBInitInfo::DuplicateName ex;
+		ex.name = s.in();
+		mico_throw(ex);
+	    }
 	}
     }
-    S_server_req_int_.push_back
+    S_server_req_int_prepared_.push_back
 	(ServerRequestInterceptor::_duplicate(interceptor));
 }
 
@@ -2724,20 +2800,23 @@ PInterceptor::PI::_exec_add_ior_interceptor
 (PortableInterceptor::IORInterceptor_ptr interceptor)
 {
     IORList::iterator it;
-    string i_name = interceptor->name();
-    if (i_name != "") {
+    CORBA::String_var i_name = interceptor->name();
+    if (strcmp(i_name.in(), "") != 0) {
 	// it's non-anonymous interceptor
 	// so we have to check if it has unique name
 	// as CORBA 2.6 (21.7.2.1) says
 	for (it = S_ior_interceptors_.begin();
 	     it != S_ior_interceptors_.end();
 	     it++) {
-	    string s = (*it)->name();
-	    if (i_name == s)
-		mico_throw(PortableInterceptor::ORBInitInfo::DuplicateName());
+	    CORBA::String_var s = (*it)->name();
+	    if (strcmp(i_name.in(), s.in()) == 0) {
+		PortableInterceptor::ORBInitInfo::DuplicateName ex;
+		ex.name = s.in();
+		mico_throw(ex);
+	    }
 	}
     }
-    S_ior_interceptors_.push_back(IORInterceptor::_duplicate(interceptor));
+    S_ior_interceptors_prepared_.push_back(IORInterceptor::_duplicate(interceptor));
 }
 
 PInterceptor::ServerRequestInfo_impl*
