@@ -20,6 +20,15 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "orb_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #define MICO_CONF_IMR
 
 #include <CORBA-SMALL.h>
@@ -27,11 +36,15 @@
 #include <mico/impl.h>
 #include <mico/template_impl.h>
 
+#endif // FAST_PCH
+
+
+using namespace std;
 
 /**************************** ReqQueueRec ***************************/
 
 
-MICO::ReqQueueRec::ReqQueueRec (MsgId id, CORBA::ORBRequest *req,
+MICO::ReqQueueRec::ReqQueueRec (CORBA::ORBMsgId id, CORBA::ORBRequest *req,
 				CORBA::Object_ptr obj,
 				CORBA::Principal_ptr pr,
 				CORBA::Boolean resp)
@@ -44,7 +57,7 @@ MICO::ReqQueueRec::ReqQueueRec (MsgId id, CORBA::ORBRequest *req,
     _type = CORBA::RequestInvoke;
 }
 
-MICO::ReqQueueRec::ReqQueueRec (MsgId id, const char *repoid,
+MICO::ReqQueueRec::ReqQueueRec (CORBA::ORBMsgId id, const char *repoid,
 				const CORBA::ORB::ObjectTag &tag)
 {
     _id = id;
@@ -56,7 +69,7 @@ MICO::ReqQueueRec::ReqQueueRec (MsgId id, const char *repoid,
     _tag = tag;
 }
 
-MICO::ReqQueueRec::ReqQueueRec (MsgId id, CORBA::Object_ptr obj)
+MICO::ReqQueueRec::ReqQueueRec (CORBA::ORBMsgId id, CORBA::Object_ptr obj)
 {
     _id = id;
     _request = CORBA::ORBRequest::_nil();
@@ -134,7 +147,7 @@ MICO::ReqQueueRec::target ()
 
 MICO::RequestQueue::RequestQueue (CORBA::ObjectAdapter *oa,
 				  CORBA::ORB_ptr orb)
-    : _oa (oa), _orb (orb), _current_id (0)
+    : _current_id (0), _oa (oa), _orb (orb)
 {
 }
 
@@ -154,7 +167,7 @@ void
 MICO::RequestQueue::exec_now ()
 {
     // reissue pending invokes ...
-    set<MsgId, less<MsgId> > seen;
+    set<CORBA::ORBMsgId, less<CORBA::ORBMsgId> > seen;
     while (_invokes.size() > 0) {
 	ReqQueueRec *inv = _invokes.front();
         _current_id = inv->id();
