@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2006 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -20,19 +20,32 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "orb_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #define MICO_CONF_IMR
 
 #include <CORBA-SMALL.h>
-#ifndef _WINDOWS
+#ifndef _WIN32
 #include <string.h>
 #endif
 #include <ctype.h>
-#include <iostream.h>
 #include <mico/impl.h>
 #include <mico/template_impl.h>
 #include <mico/util.h>
 #include <mico/throw.h>
 
+#endif // FAST_PCH
+
+
+using namespace std;
+
 #define TK_RECURSIVE ((int)0xffffffff)
 
 
@@ -123,12 +136,7 @@ CORBA::TypeCode::from_string (const char *_ior)
         b.put ((mico_from_xdigit (s[i]) << 4) | mico_from_xdigit (s[i+1]));
     }
 
-#ifdef _WINDOWS
-    MICO::CDRDecoder dc (&b, FALSE, CORBA::DefaultEndian,
-			 0, TRUE, 0, TRUE);
-#else
     MICO::CDRDecoder dc (&b, FALSE);
-#endif
 
     Octet bo;
     if (!dc.get_octet (bo))
@@ -2218,6 +2226,11 @@ CORBA::TypeCodeConst::TypeCodeConst (const char *s)
 {
 }
 
+CORBA::TypeCodeConst::~TypeCodeConst()
+{
+    CORBA::release(_tc);
+}
+
 CORBA::TypeCodeConst &
 CORBA::TypeCodeConst::operator= (const char *s)
 {
@@ -2908,7 +2921,6 @@ static struct InitTypeCodeConstants {
     }
 } __init_tc_constants;
 
-#ifdef HAVE_NAMESPACE
 namespace CORBA {
     CORBA::TypeCode_ptr _tc_null;
     CORBA::TypeCode_ptr _tc_void;
@@ -2940,36 +2952,4 @@ namespace CORBA {
 #include <mico/sysexc.h>
 #undef SYSEXC
 
-};
-#else
-CORBA::TypeCode_ptr CORBA::_tc_null;
-CORBA::TypeCode_ptr CORBA::_tc_void;
-CORBA::TypeCode_ptr CORBA::_tc_short;
-CORBA::TypeCode_ptr CORBA::_tc_long;
-CORBA::TypeCode_ptr CORBA::_tc_longlong;
-CORBA::TypeCode_ptr CORBA::_tc_ushort;
-CORBA::TypeCode_ptr CORBA::_tc_ulong;
-CORBA::TypeCode_ptr CORBA::_tc_ulonglong;
-CORBA::TypeCode_ptr CORBA::_tc_float;
-CORBA::TypeCode_ptr CORBA::_tc_double;
-CORBA::TypeCode_ptr CORBA::_tc_longdouble;
-CORBA::TypeCode_ptr CORBA::_tc_boolean;
-CORBA::TypeCode_ptr CORBA::_tc_char;
-CORBA::TypeCode_ptr CORBA::_tc_wchar;
-CORBA::TypeCode_ptr CORBA::_tc_octet;
-CORBA::TypeCode_ptr CORBA::_tc_any;
-CORBA::TypeCode_ptr CORBA::_tc_TypeCode;
-CORBA::TypeCode_ptr CORBA::_tc_Principal;
-CORBA::TypeCode_ptr CORBA::_tc_Object;
-CORBA::TypeCode_ptr CORBA::_tc_ValueBase;
-CORBA::TypeCode_ptr CORBA::_tc_AbstractBase; // extension
-CORBA::TypeCode_ptr CORBA::_tc_string;
-CORBA::TypeCode_ptr CORBA::_tc_wstring;
-CORBA::TypeCode_ptr CORBA::_tc_Context; // extension
-CORBA::TypeCode_ptr CORBA::_tc_NamedValue; // extension
-
-#define SYSEXC(name) CORBA::TypeCode_ptr CORBA::_tc_ ## name;
-#include <mico/sysexc.h>
-#undef SYSEXC
-
-#endif
+}
