@@ -1,6 +1,7 @@
 /*
  *  Code Set Converters for MICO
  *  Copyright (C) 1997 Marcus Mueller & Thomas Holubar
+ *  Copyright (c) 1998-2006 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -23,6 +24,9 @@
  *	97/07/01 0.1    mueller         CREATED
  */
 
+#ifdef __COMO__
+#pragma no_pch
+#endif // __COMO__
 #include <stdio.h>
 #include <string.h>
 
@@ -35,7 +39,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifdef _WINDOWS
+#ifdef _WIN32
 #pragma warning (disable: 4305 4309 4244 4018)
 // pragma warning (default: 4305 ) // turn on
 
@@ -61,10 +65,10 @@ static const char uni2ebcArray[] =  /* beginning with 0x20 (32) */
   0xA7, 0xA8, 0xA9, 0x8B, 0x6A, 0x9B, '\0', '\0'   /* 0x78-0x7F (120-127) */
 };
 
-static const cexcept exc2ebcArray[] =
-{
-  { 0x00A2 , 0x4A } , { 0x00AC , 0x5F } , { 0x00DF , 0xE1 }
-};
+//  static const cexcept exc2ebcArray[] =
+//  {
+//    { 0x00A2 , 0x4A } , { 0x00AC , 0x5F } , { 0x00DF , 0xE1 }
+//  };
 
 static const uni_ubyte uni2htmlArray[] =  /* beginning with 0xa0 (160) */
 {
@@ -213,6 +217,58 @@ static const cexcept exc2koiArray[] =
   { 0x2592 , 0x91 } , { 0x2593 , 0x92 }
 };
 
+static const char uni2ibm866Array1[] =  /* beginning with 0x0410 (1040) */
+{
+  0x80, 0x81, 0x82, 0x83,  /* 0x0410-0x0413 (1040-1043) */
+  0x84, 0x85, 0x86, 0x87,  /* 0x0414-0x0417 (1044-1047) */
+  0x88, 0x89, 0x8A, 0x8B,  /* 0x0418-0x041B (1048-1051) */
+  0x8C, 0x8D, 0x8E, 0x8F,  /* 0x041C-0x041F (1042-1055) */
+
+  0x90, 0x91, 0x92, 0x93,  /* 0x0420-0x0423 (1056-1059) */
+  0x94, 0x95, 0x96, 0x97,  /* 0x0424-0x0427 (1060-1063) */
+  0x98, 0x99, 0x9A, 0x9B,  /* 0x0428-0x042B (1064-1067) */
+  0x9C, 0x9D, 0x9E, 0x9F,  /* 0x042C-0x042F (1068-1071) */
+
+  0xA0, 0xA1, 0xA2, 0xA3,  /* 0x0430-0x0433 (1072-1075) */
+  0xA4, 0xA5, 0xA6, 0xA7,  /* 0x0434-0x0437 (1076-1079) */
+  0xA8, 0xA9, 0xAA, 0xAB,  /* 0x0438-0x043B (1080-1083) */
+  0xAC, 0xAD, 0xAE, 0xAF,  /* 0x043C-0x043F (1084-1087) */
+
+  0xE0, 0xE1, 0xE2, 0xE3,  /* 0x0440-0x0443 (1088-1091) */
+  0xE4, 0xE5, 0xE6, 0xE7,  /* 0x0444-0x0447 (1092-1095) */
+  0xE8, 0xE9, 0xEA, 0xEB,  /* 0x0448-0x044B (1096-1099) */
+  0xEC, 0xED, 0xEE, 0xEF,  /* 0x044C-0x044F (1100-1103) */
+};
+
+static const char uni2ibm866Array2[] =  /* beginning with 0x2550 (9552) */
+{
+  0xCD, 0xBA, 0xD5, 0xD6,  /* 0x2550-0x2553 (9552-9555) */
+  0xC9, 0xB8, 0xB7, 0xBB,  /* 0x2554-0x2557 (9556-9559) */
+  0xD4, 0xD3, 0xC8, 0xBE,  /* 0x2558-0x255B (9560-9563) */
+  0xBD, 0xBC, 0xC6, 0xC7,  /* 0x255C-0x255F (9564-9567) */
+
+  0xCC, 0xB5, 0xB6, 0xB9,  /* 0x2560-0x2563 (9568-9571) */
+  0xD1, 0xD2, 0xCB, 0xCF,  /* 0x2564-0x2567 (9572-9575) */
+  0xD0, 0xCA, 0xD8, 0xD7,  /* 0x2568-0x256B (9576-9579) */
+  0xCE,                    /* 0x256C        (9578     ) */
+};
+
+static const cexcept exc2ibm866Array[] =
+{
+{ 0xA0   , 0xFF } , { 0xA4   , 0xFD } , { 0xB0   , 0xF8 } ,
+{ 0xB7   , 0xFA } , { 0x0401 , 0xF0 } , { 0x0404 , 0xF2 } ,
+{ 0x0407 , 0xF4 } , { 0x040E , 0xF6 } , { 0x0451 , 0xF1 } ,
+{ 0x0454 , 0xF3 } , { 0x0457 , 0xF5 } , { 0x045E , 0xF7 } ,
+{ 0x2116 , 0xFC } , { 0x2219 , 0xF9 } , { 0x221A , 0xFB } ,
+{ 0x2500 , 0xC4 } , { 0x2502 , 0xB3 } , { 0x250C , 0xDA } ,
+{ 0x2510 , 0xBF } , { 0x2514 , 0xC0 } , { 0x2518 , 0xD9 } ,
+{ 0x251C , 0xC3 } , { 0x2524 , 0xB4 } , { 0x252C , 0xC2 } ,
+{ 0x2534 , 0xC1 } , { 0x253C , 0xC5 } , { 0x2580 , 0xDF } ,
+{ 0x2584 , 0xDC } , { 0x2588 , 0xDB } , { 0x258C , 0xDD } ,
+{ 0x2590 , 0xDE } , { 0x2591 , 0xB0 } , { 0x2592 , 0xB1 } ,
+{ 0x2593 , 0xB2 } , { 0x25A0 , 0xFE } ,
+};
+
 static const char uni2isoArray[] =  /* beginning with 0x0100 (256) */
 {
   0xC0, 0xE0, 0xC3, 0xE3,  /* 0x0100-0x0103 (256-259) */
@@ -504,6 +560,14 @@ static const cfromunitable uni2koiTable2 =
   { uni2koiArray2, 0x2550 /* 9552 */, sizeof(uni2koiArray2),
     0x00000000 };
 
+static const cfromunitable uni2ibm866Table1 =
+  { uni2ibm866Array1, 0x0410 /* 1040 */, sizeof(uni2ibm866Array1),
+    0x00000000 };
+
+static const cfromunitable uni2ibm866Table2 =
+  { uni2ibm866Array2, 0x2550 /* 9552 */, sizeof(uni2ibm866Array2),
+    0x00000000 };
+
 static const cfromunitable uni2isoTable =
   { uni2isoArray, 0x0100 /*  256 */, sizeof(uni2isoArray),
     0x00000000 };
@@ -515,8 +579,8 @@ static const cfromunitable uni2ibmTable2 =
   { uni2ibmArray2, 0x2550 /* 9552 */, sizeof(uni2ibmArray2), 0xF7FF007E };
 
 
-static const cexcepttable exc2ebcTable =
-  { exc2ebcArray, 3 };
+//  static const cexcepttable exc2ebcTable =
+//    { exc2ebcArray, 3 };
 
 static const cexcepttable exc2macTable =
   { exc2macArray, 50 };
@@ -524,6 +588,9 @@ static const cexcepttable exc2macTable =
 static const cexcepttable exc2koiTable =
   { exc2koiArray, 35 };
 
+static const cexcepttable exc2ibm866Table =
+  { exc2ibm866Array, 35 };
+
 static const cexcepttable exc2iso2Table =
   { exc2iso2Array, 5 };
 
@@ -1290,6 +1357,13 @@ cont:         dest[di++] = ';';
       ibmcheck    = &uni_ibm4372uniTable;
     break;
 
+    case C_IBM_866:
+      table1      = &uni2ibm866Table1;
+      table2      = &uni2ibm866Table2;
+      unknown     = C_IBM_866_UNKNOWN;
+      except      = &exc2ibm866Table;
+    break;
+
     default: return(C_UNKNOWN_FORMAT);
   }
 
@@ -1333,7 +1407,7 @@ cont:         dest[di++] = ';';
     {
       if( (check!=NULL) && (character <= 0xFF) )
         if( (character >= check->offset) &&
-            (character <  check->offset + check->size) )
+            ((uni_slong)character <  check->offset + check->size) )
           if( check->array[ character - check->offset ] == character )
           {
             dest[di] = (char)character;
@@ -1341,7 +1415,7 @@ cont:         dest[di++] = ';';
           }
 
       if( trans && (character >= table1->offset) && 
-                   (character <  table1->offset + table1->size) )
+                   ((uni_slong)character < table1->offset + table1->size) )
       {
         dest[di] = table1->array[character - table1->offset];
         if(check!=NULL)
@@ -1364,7 +1438,7 @@ cont:         dest[di++] = ';';
 
       if( trans && (table2!=NULL) )
         if( (character >= table2->offset) && 
-            (character <  table2->offset + table2->size) )
+            ((uni_slong)character <  table2->offset + table2->size) )
         {
           dest[di] = table2->array[character - table2->offset];
           if(check!=NULL)
