@@ -1,6 +1,7 @@
 /*
  *  Code Set Converters for MICO
  *  Copyright (C) 1997 Marcus Mueller & Thomas Holubar
+ *  Copyright (c) 1998-2006 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -212,7 +213,7 @@ static const uni_ushort koi2uniArray[] =  /* beginning with 0x80 (128) */
   0x044C, 0x044B, 0x0437, 0x0448,  /* 0xD8-0xDB (216-219) */
   0x044D, 0x0449, 0x0447, 0x044A,  /* 0xDC-0xDF (220-223) */
 
-  0x041E, 0x0410, 0x0411, 0x0426,  /* 0xE0-0xE3 (224-227) */
+  0x042E, 0x0410, 0x0411, 0x0426,  /* 0xE0-0xE3 (224-227) */
   0x0414, 0x0415, 0x0424, 0x0413,  /* 0xE4-0xE7 (228-231) */
   0x0425, 0x0418, 0x0419, 0x041A,  /* 0xE8-0xEB (232-235) */
   0x041B, 0x041C, 0x041D, 0x041E,  /* 0xEC-0xEF (236-239) */
@@ -472,6 +473,50 @@ const uni_ushort ibm8652uniArray[] =  /* beginning with 0x97 (151) */
   0xBC  , 0xA1  , 0xAB  , 0xA4  ,  /* 0xAC-0xAF (172-175) */
 };
 
+const uni_ushort ibm8662uniArray[] =  /* beginning with 0x80 (128) */
+{
+  0x0410, 0x0411, 0x0412, 0x0413,  /* 0x80-0x83 (128-131) */
+  0x0414, 0x0415, 0x0416, 0x0417,  /* 0x84-0x87 (132-135) */
+  0x0418, 0x0419, 0x041A, 0x041B,  /* 0x88-0x8B (136-139) */
+  0x041C, 0x041D, 0x041E, 0x041F,  /* 0x8C-0x8F (140-143) */
+
+  0x0420, 0x0421, 0x0422, 0x0423,  /* 0x90-0x93 (144-147) */
+  0x0424, 0x0425, 0x0426, 0x0427,  /* 0x94-0x97 (148-151) */
+  0x0428, 0x0429, 0x042A, 0x042B,  /* 0x98-0x9B (152-155) */
+  0x042C, 0x042D, 0x042E, 0x042F,  /* 0x9C-0x9F (156-159) */
+
+  0x0430, 0x0431, 0x0432, 0x0433,  /* 0xA0-0xA3 (160-163) */
+  0x0434, 0x0435, 0x0436, 0x0437,  /* 0xA4-0xA7 (164-167) */
+  0x0438, 0x0439, 0x043A, 0x043B,  /* 0xA8-0xAB (168-171) */
+  0x043C, 0x043D, 0x043E, 0x043F,  /* 0xAC-0xAF (172-175) */
+
+  0x2591, 0x2592, 0x2593, 0x2502,  /* 0xB0-0xB3 (176-179) */
+  0x2524, 0x2561, 0x2562, 0x2556,  /* 0xB4-0xB7 (180-183) */
+  0x2555, 0x2563, 0x2551, 0x2557,  /* 0xB8-0xBB (184-187) */
+  0x255D, 0x255C, 0x255B, 0x2510,  /* 0xBC-0xBF (188-191) */
+
+  0x2514, 0x2534, 0x252C, 0x251C,  /* 0xC0-0xC3 (192-195) */
+  0x2500, 0x253C, 0x255E, 0x255F,  /* 0xC4-0xC7 (196-199) */
+  0x255A, 0x2554, 0x2569, 0x2566,  /* 0xC8-0xCB (200-203) */
+  0x2560, 0x2550, 0x256C, 0x2567,  /* 0xCC-0xCF (204-207) */
+
+  0x2568, 0x2564, 0x2565, 0x2559,  /* 0xD0-0xD3 (208-211) */
+  0x2558, 0x2552, 0x2553, 0x256B,  /* 0xD4-0xD7 (212-215) */
+  0x256A, 0x2518, 0x250C, 0x2588,  /* 0xD8-0xDB (216-219) */
+  0x2584, 0x258C, 0x2590, 0x2580,  /* 0xDC-0xDF (220-223) */
+
+  0x0440, 0x0441, 0x0442, 0x0443,  /* 0xE0-0xE3 (224-227) */
+  0x0444, 0x0445, 0x0446, 0x0447,  /* 0xE4-0xE7 (228-231) */
+  0x0448, 0x0449, 0x044A, 0x044B,  /* 0xE8-0xEB (232-235) */
+  0x044C, 0x044D, 0x044E, 0x044F,  /* 0xEC-0xEF (236-239) */
+
+  0x0401, 0x0451, 0x0404, 0x0454,  /* 0xF0-0xF3 (240-243) */
+  0x0407, 0x0457, 0x040E, 0x045E,  /* 0xF4-0xF7 (244-247) */
+  0x00B0, 0x2219, 0x00B7, 0x221A,  /* 0xF8-0xFB (248-251) */
+  0x2116, 0x00A4, 0x25A0, 0x00A0,  /* 0xFC-0xFF (252-255) */
+
+};
+
 static const uni_ushort macarr2uniArray[] = /* beginning with 0x1C ( 28) */
 {
   0x2190, 0x2192, 0x2191, 0x2193   /* 0x1C-0x1F ( 28- 31) */
@@ -708,6 +753,9 @@ const ctounitable uni_ibm8632uniTable =
 const ctounitable uni_ibm8652uniTable =
   { ibm8652uniArray, 0x97 /* 151 */, sizeof(ibm8652uniArray) / sizeof(uni_ushort) };
 
+const ctounitable uni_ibm8662uniTable =
+  { ibm8662uniArray, 0x80 /* 128 */, sizeof(ibm8662uniArray) / sizeof(uni_ushort) };
+
 const ctounitable uni_mac2uniTable =
   { mac2uniArray, 0x80 /* 128 */, sizeof(mac2uniArray) / sizeof(uni_ushort) };
 
@@ -1394,6 +1442,12 @@ uni_slong uni_toUTF8  (char *utf8, const char *src, uni_uword chars,
       table3 = &uni_ibm2uniTable;
     break;
 
+    case C_IBM_866:
+      table1 = &uni_ibm8662uniTable;
+      table2 = &uni_ibm4372uniTable;
+      table3 = &uni_ibm2uniTable;
+    break;
+
     default: return(C_UNKNOWN_FORMAT);
   }
 
