@@ -23,13 +23,16 @@
  *	97/06/27 0.1    mueller         CREATED
  */
 
+#ifdef __COMO__
+#pragma no_pch
+#endif // __COMO__
 #include <string.h>
 #include "uni_unicode.h"
 #include "uni_base64.h"
 #include "uni_errors.h"
 #include "uni_support.h"
 
-#ifdef _WINDOWS
+#ifdef _WIN32
 #pragma warning (disable: 4305 4309 4244 4018)
 // pragma warning (default: 4305 ) // turn on
 #endif
@@ -159,7 +162,7 @@ C_EXPORT uni_slong uni_utf8toucs4(uni_ulong *ucs4, const char *utf8,
 {
   register const uni_ubyte *utf=(uni_ubyte*)utf8;
   register uni_ubyte read=0;
-  register uni_ulong RC;
+  register uni_ulong RC=0;
 
   if( (utf[0]) && ( (utf[0] & 0xC0) != 0x80 ) )
   {
