@@ -1,6 +1,6 @@
 /*
  *  MICO --- an Open Source CORBA implementation
- *  Copyright (c) 1997-2001 by The Mico Team
+ *  Copyright (c) 1997-2006 by The Mico Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -72,7 +72,13 @@ void
 mico_assert (const char *file, int line)
 {
 #ifdef HAVE_THREADS
-    cout << "[" << ((MICO_ULong) OSMisc::timestamp()) << " - " << MICOMT::Thread::self() << "] ";
+    cout << "[" << ((MICO_ULong) OSMisc::timestamp()) << " - "
+#ifdef NEED_THREADID_OPERATORS
+		<< MICOMT::Thread::self().p
+#else // NEED_THREADID_OPERATORS
+		<< MICOMT::Thread::self()
+#endif // NEED_THREADID_OPERATORS
+		<< "] ";
 #endif
     cout << file << ":" << line << ": assertion failed" << endl;
 #ifdef USE_MEMTRACE
@@ -212,6 +218,115 @@ xdec (OSMisc::ulonglong i)
 #endif
 }
 
+wstring
+wxdec (int i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+    ostr << i;
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+wstring
+wxdec (long i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+    ostr << i;
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+wstring
+wxdec (OSMisc::longlong i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+#if defined(_WIN32) && !defined(__MINGW32__)
+    ostr << long(i);
+#else
+    ostr << i;
+#endif
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+wstring
+wxdec (unsigned int i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+    ostr << i;
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+wstring
+wxdec (unsigned long i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+    ostr << i;
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+wstring
+wxdec (OSMisc::ulonglong i)
+{
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+    wostringstream ostr;
+#if defined(_WIN32) && !defined(__MINGW32__)
+    ostr << unsigned long(i);
+#else
+    ostr << i;
+#endif
+    return ostr.str();
+#else
+    assert(0);
+    return wstring(L"");
+#endif
+}
+
+string
+wstr2str(const wstring& str)
+{
+    string ret = "";
+    for (unsigned int i = 0; i < str.length(); i++) {
+	if (str[i] <= 0177)
+	    ret += (char)str[i];
+	else
+	    assert(0);
+    }
+    return ret;
+}
+
+wstring
+str2wstr(const string& str)
+{
+    wstring ret = L"";
+    for (unsigned int i = 0; i < str.length(); i++) {
+	ret += str[i];
+    }
+    return ret;
+}
+
 size_t
 xwcslen (const wchar_t *s)
 {
@@ -357,74 +472,6 @@ mico_string_hash (const char *s, CORBA::ULong max)
 }
 
 
-/************************** MethodDispatcher **************************/
-
-
-CORBA::InterfaceDispatcher::~InterfaceDispatcher ()
-{
-}
-
-CORBA::MethodDispatcher::~MethodDispatcher ()
-{
-    for (mico_vec_size_type i = 0; i < _dispatcher.size(); ++i)
-	delete _dispatcher[i];
-}
-
-void
-CORBA::MethodDispatcher::register_dispatcher (InterfaceDispatcher *disp)
-{
-    _dispatcher.push_back (disp);
-}
-
-void
-CORBA::MethodDispatcher::invoke (CORBA::ServerRequest_ptr _req,
-				 CORBA::Environment &_env)
-{
-    for (mico_vec_size_type i=0; i < _dispatcher.size(); ++i) {
-	if (_dispatcher[i]->dispatch (_req, _env))
-	    return;
-    }
-#ifdef _POCKET_PC
-    MICO_NOT_IMPLEMENTED;
-#else
-	_req->exception (new BAD_OPERATION);
-#endif
-}
-
-
-/*********************** StaticMethodDispatcher ************************/
-
-
-CORBA::StaticInterfaceDispatcher::~StaticInterfaceDispatcher ()
-{
-}
-
-CORBA::StaticMethodDispatcher::~StaticMethodDispatcher ()
-{
-    for (mico_vec_size_type i = 0; i < _dispatcher.size(); ++i)
-	delete _dispatcher[i];
-}
-
-void
-CORBA::StaticMethodDispatcher::
-                    register_dispatcher (StaticInterfaceDispatcher *disp)
-{
-    _dispatcher.push_back (disp);
-}
-
-void
-CORBA::StaticMethodDispatcher::invoke (CORBA::StaticServerRequest_ptr _req,
-				       CORBA::Environment &_env)
-{
-    for (mico_vec_size_type i=0; i < _dispatcher.size(); ++i) {
-	if (_dispatcher[i]->dispatch (_req, _env))
-	    return;
-    }
-    _req->set_exception (new BAD_OPERATION);
-    _req->write_results();
-}
-
-
 /***************************** MICODebug ******************************/
 
 
@@ -1176,7 +1223,13 @@ mico_double2ieee (CORBA::Octet ieee[8], CORBA::Double d)
 	ie.s = (d < 0);
 	ie.e = exp;
 	ie.f1 = (unsigned long)ldexp (frac, DBL_FRC1_BITS);
-	ie.f2 = (unsigned long)ldexp (frac, DBL_FRC_BITS);
+        // kcg: what's right, this: (following two lines fixes double
+        // encoding issue on big-endian hosts (sparc/ppc64), test case
+        // is test/idl/37
+        double mantissa = ldexp( frac , DBL_FRC_BITS );
+        ie.f2 = (unsigned long)fmod( mantissa , 4294967296.0 ); // 2^32 = 4294967296
+        // kcg: or this:
+//	ie.f2 = (unsigned long)ldexp (frac, DBL_FRC_BITS);
     }
 }
 
