@@ -20,16 +20,28 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "orb_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #include <CORBA.h>
-#ifndef _WINDOWS
+#ifndef _WIN32
 #include <string.h>
 #endif
-#include <iostream.h>
 #include <mico/impl.h>
 #include <mico/template_impl.h>
 #include <mico/util.h>
 #include <mico/throw.h>
 
+#endif // FAST_PCH
+
+
+using namespace std;
 
 //-------------------
 
@@ -162,10 +174,16 @@ CORBA::ValueBase::_demarshal (CORBA::DataDecoder &dc, ValueBase *&vb,
 	return TRUE;
     }
 
-    vb = CORBA::ValueBase::_create (repoids, repoid);
-    if (!vb)
-	// no implementation ...
-	return FALSE;
+    // vb is null for a non-boxed value
+    // vb is non-null for a boxed value (which was constructed by a stub
+    //                                   and does not need a value factory)
+    if (!vb) {
+        // non-boxed value: use value factory
+        vb = CORBA::ValueBase::_create (repoids, repoid);
+        if (!vb)
+	    // no implementation ...
+	    return FALSE;
+    }
 
     dc.valuestate()->visited[vid] = vb;
 
@@ -184,7 +202,7 @@ CORBA::ValueBase::_copy_value ()
   CORBA::DataEncoder::ValueState evstate;
   CORBA::DataDecoder::ValueState dvstate;
 
-  CORBA::ValueBase * res;
+  CORBA::ValueBase * res = NULL;
   CORBA::Boolean ret;
   vector<string> repoids;
 
@@ -262,20 +280,24 @@ CORBA::ValueFactory
 CORBA::ORB::register_value_factory (const char *repoid, ValueFactory factory)
 {
     ValueFactory vf = lookup_value_factory (repoid);
+    _value_facs.lock();
     factory->_add_ref();
     _value_facs[repoid] = factory;
+    _value_facs.unlock();
     return vf;
 }
 
 void
 CORBA::ORB::unregister_value_factory (const char *repoid)
 {
+    MICOMT::AutoLock l(_value_facs);
     _value_facs.erase (repoid);
 }
 
 CORBA::ValueFactory
 CORBA::ORB::lookup_value_factory (const char *repoid)
 {
+    MICOMT::AutoLock l(_value_facs);
     ValueFactoryMap::iterator i = _value_facs.find (repoid);
     if (i == _value_facs.end())
 	return 0;
@@ -381,7 +403,7 @@ CORBA::AbstractBase::_demarshal (DataDecoder &dc, AbstractBase *&ab)
     ab = new UnknownAbstract (obj, 0);
   }
   else {
-    ValueBase * val;
+    ValueBase * val = NULL;
     if (!CORBA::_stc_ValueBase->demarshal (dc, &val)) {
       return FALSE;
     }
