@@ -20,9 +20,20 @@
  *  http://www.mico.org/
  */
 
+#ifdef FAST_PCH
+#include "orb_pch.h"
+#endif // FAST_PCH
+#ifdef __COMO__
+#pragma hdrstop
+#endif // __COMO__
+
+#ifndef FAST_PCH
+
 #include <CORBA.h>
 #include <mico/template_impl.h>
 
+#endif // FAST_PCH
+
 /*
  * StringValue and WStringValue factories
  */
