@@ -8,7 +8,7 @@
 #include <unistd.h>
 #include <signal.h>
 
-class SomeIface_impl : virtual public SomeIface_skel {
+class SomeIface_impl : virtual public POA_SomeIface {
 public:
     void f ()
     {
@@ -21,10 +21,12 @@ public:
 int main (int argc, char *argv[])
 {
     CORBA::ORB_var orb = CORBA::ORB_init (argc, argv, "mico-local-orb");
-    CORBA::BOA_var boa = orb->BOA_init (argc, argv, "mico-local-boa");
-
-    (void)new SomeIface_impl;
-    boa->impl_is_ready (CORBA::ImplementationDef::_nil());
+    CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
+    PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);
+    PortableServer::POAManager_var mgr = poa->the_POAManager();
+    SomeIface_impl* servant = new SomeIface_impl;
+    servant->_this();
+    mgr->activate();
     orb->run ();
     return 0;
 }
