@@ -711,7 +711,7 @@ CORBA::StaticTypeInfo *_stc_LongNode = new TCLongNode;
 //--------------------
 
 
-class Interface_impl : virtual public Interface_skel {
+class Interface_impl : virtual public POA_Interface {
 };
 
 
@@ -894,7 +894,8 @@ do_tests ()
     // context, princiapl
 
     // interface
-    Interface_ptr iface_i = new Interface_impl;
+    Interface_impl* iimpl = new Interface_impl;
+    Interface_ptr iface_i = iimpl->_this();
     Checker<ObjCmp, Interface_ptr> iface_s (_stc_Interface, iface_i);
 
     // sequences of basic types
