@@ -1,5 +1,6 @@
 #define FORCE_MARSHALLING
 
+#define MICO_CONF_POA
 #include <CORBA-SMALL.h>
 #include "sequence.h"
 #ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
@@ -13,7 +14,7 @@
 
 using namespace std;
 
-class foo_impl : virtual public foo_skel
+class foo_impl : virtual public POA_foo
 {
 public:
   foo_impl()
@@ -94,17 +95,21 @@ int main( int argc, char *argv[] )
 {
   // ORB initialization
   CORBA::ORB_var orb = CORBA::ORB_init( argc, argv, "mico-local-orb" );
-  CORBA::BOA_ptr boa = orb->BOA_init (argc, argv, "mico-local-boa");
+  CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
+  PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);
+  PortableServer::POAManager_var mgr = poa->the_POAManager();
 
   foo_impl* server = new foo_impl;
+  foo_var foo = server->_this();
   string ref;
 
+  mgr->activate();
+
   if( argc >= 2 && *argv[ 1 ] == 's' ) {
     ofstream objid( "server.objid" );
-    CORBA::String_var ref = orb->object_to_string( server );
+    CORBA::String_var ref = orb->object_to_string( foo );
     objid << ref.in();
     objid.close();
-    boa->impl_is_ready( 0 );
     orb->run ();
     return 0;
   } else if( argc >= 2 && *argv[ 1 ] == 'c' ) {
@@ -114,17 +119,17 @@ int main( int argc, char *argv[] )
     cerr << "usage: " << argv[ 0 ] << "[c|s]" << endl;
     return 1;
   } else {
-    CORBA::String_var s = orb->object_to_string( server );
+    CORBA::String_var s = orb->object_to_string( foo );
     ref = s;
   }
   
   // client side
 #ifdef FORCE_MARSHALLING
-  CORBA::Object_var obj = new CORBA::Object( new CORBA::IOR( ref.c_str() ) );
+  CORBA::Object_var obj2 = new CORBA::Object( new CORBA::IOR( ref.c_str() ) );
 #else
-  CORBA::Object_var obj = orb->string_to_object( ref.c_str() );
+  CORBA::Object_var obj2 = orb->string_to_object( ref.c_str() );
 #endif
-  foo_var client = foo::_narrow( obj );
+  foo_var client = foo::_narrow( obj2 );
   
   S s1;
   s1.x = 42;
@@ -226,5 +231,5 @@ int main( int argc, char *argv[] )
   strseq[ 0 ] = (const char *) "Hello";
   strseq[ 1 ] = (const char *) "World";
   client->bar3( strseq );
-  CORBA::release( server );
+  CORBA::release( foo );
 }
