@@ -1,8 +1,13 @@
-#include <iostream.h>
 #include <CORBA-SMALL.h>
 #include "const.h"
+#ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iostream>
+#else // HAVE_ANSI_CPLUSPLUS_HEADERS
+#include <iostream.h>
+#endif // HAVE_ANSI_CPLUSPLUS_HEADERS
 
 
+using namespace std;
 
 int main( int argc, char *argv[] )
 {
@@ -21,4 +26,5 @@ int main( int argc, char *argv[] )
   cout << c10 << endl;
   cout << foo::c11 << endl;
   cout << foo::c12 << endl;
+  cout << foo::msg << endl;
 }
