@@ -1,5 +1,5 @@
 #define FORCE_MARSHALLING
-
+#define MICO_CONF_POA
 #include <CORBA-SMALL.h>
 #include "union.h"
 #ifdef HAVE_ANSI_CPLUSPLUS_HEADERS
@@ -11,7 +11,7 @@
 
 using namespace std;
 
-class foo_impl : virtual public foo_skel
+class foo_impl : virtual public POA_foo
 {
 public:
   foo_impl()
@@ -33,18 +33,23 @@ int main( int argc, char *argv[] )
 {
   // ORB initialization
   CORBA::ORB_var orb = CORBA::ORB_init( argc, argv, "mico-local-orb" );
+  CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
+  PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);
+  PortableServer::POAManager_var mgr = poa->the_POAManager();
+  mgr->activate();
 
   // server side
-  foo_impl* server = new foo_impl;
+  foo_impl* foo = new foo_impl;
+  foo_ptr server = foo->_this();
   CORBA::String_var ref = orb->object_to_string( server );
   
   //----------------------------------------------------------------
   
   // client side
 #ifdef FORCE_MARSHALLING
-  CORBA::Object_var obj = new CORBA::Object( new CORBA::IOR( ref ) );
+  obj = new CORBA::Object( new CORBA::IOR( ref ) );
 #else
-  CORBA::Object_var obj = orb->string_to_object( ref );
+  obj = orb->string_to_object( ref );
 #endif
   foo_var client = foo::_narrow( obj );
 
