@@ -21,7 +21,7 @@ create_request( CORBA::Object_ptr obj, const char* opname )
       std::cout << "oops: no operation dii()" << std::endl;
       exit(1);
     }
-    CORBA::OperationDef_var op = CORBA::OperationDef::_narrow (cs[0l]);
+    CORBA::OperationDef_var op = CORBA::OperationDef::_narrow (cs[0u]);
     op_excpts = op->exceptions();
 
     // create request and fill it with exceptions
