@@ -469,9 +469,13 @@ public void mouseExited (MouseEvent e)
 
 public void mousePressed (MouseEvent e)
     {
+      // Left mouse detection for JDK 1.3
+      if( (e.getModifiers() & InputEvent.BUTTON1_MASK) != 0 )
+	Select( e );
+      // Left mouse detection for pre-JDK 1.3
       if( e.getModifiers() == 0 )
 	Select( e );
-      if( ( e.getModifiers() & InputEvent.BUTTON3_MASK ) != 0 )
+      if( (e.getModifiers() & InputEvent.BUTTON3_MASK) != 0 )
 	Pick( e );
     }
 
