@@ -211,7 +211,7 @@ DII::setValue (CORBA::Any &a, ConceptualGraph *rootcg, int level)
 		return false;
 	    cn->setValue (us);
 	} else if (type == "STRING") {
-	    char *s;
+	    const char *s;
 	    if (!(a >>= s))
 		return false;
 	    setInst (cn, (const char *)s);
@@ -384,12 +384,12 @@ DII::checkOp (CORBA::Object_ptr obj, CORBA::Request_ptr req)
 
     CORBA::TypeCode_var optc = req->result()->value()->type();
     CORBA::TypeCode_var irtc = opdef->result();
-    if (!irtc->subtype (optc))
+    if (!irtc->equivalent (optc))
 	return DIIError ("wrong result type");
 
     for (CORBA::ULong i = 0; i < params->length(); ++i) {
 	optc = req->arguments()->item(i)->value()->type();
-	irtc = params[i].type;
+	irtc = params[i].type_def->type();
 	CORBA::Flags f = req->arguments()->item(i)->flags();
 
 	string s = "for argument <";
@@ -400,14 +400,14 @@ DII::checkOp (CORBA::Object_ptr obj, CORBA::Request_ptr req)
 	case CORBA::PARAM_IN:
 	    if (f != CORBA::ARG_IN)
 		return DIIError (string("wrong direction ") + s);
-	    if (!optc->subtype (irtc))
+	    if (!optc->equivalent (irtc))
 		return DIIError (string("wrong type ") + s);
 	    break;
 
 	case CORBA::PARAM_OUT:
 	    if (f != CORBA::ARG_OUT)
 		return DIIError (string("wrong direction ") + s);
-	    if (!irtc->subtype (optc))
+	    if (!irtc->equivalent (optc))
 		return DIIError (string("wrong type ") + s);
 	    break;
 
